<?php

defined('ABSPATH') || exit;

class Koala_WMSA_Admin {

	public function __construct() {

		add_action('admin_menu', array( $this, 'add_submenu_woocommerce' ));
		add_action('admin_init', array( $this, 'multiple_address_add_setting_files' ));

		add_action('woocommerce_admin_order_data_after_shipping_address', array( $this, 'wmsa_admin_shipping_custom_fields' ));
		add_action('woocommerce_process_shop_order_meta', array( $this, 'wmsa_save_custom_shiiping_fields' ));
	}

	public function wmsa_admin_shipping_custom_fields() {

		global $post;
		$shipping_email = get_post_meta($post->ID, '_shipping_email', true);
		$shipping_phone = get_post_meta($post->ID, '_shipping_phone', true);
		?>
		<div class="address">
			<p><strong><?php esc_html_e('Email address', 'koala-multiple-customer-addresses'); ?>:</strong>
				<a href="mailto:<?php echo esc_attr($shipping_email); ?>"><?php echo esc_attr($shipping_email); ?></a>
			</p>
			<p><strong><?php esc_html_e('Phone', 'koala-multiple-customer-addresses'); ?>:</strong>
				<a href="tel:<?php echo esc_attr($shipping_phone); ?>"> <?php echo esc_attr($shipping_phone); ?></a>
			</p>
		</div>
		<div class="edit_address">
			<?php
			woocommerce_wp_text_input(
				array(
					'id'            => 'shipping_em',
					'label'         => 'Email address:',
					'value'         => $shipping_email,
					'wrapper_class' => 'form-field-wide',
				)
			);
			woocommerce_wp_text_input(
				array(
					'id'            => 'shipping_ph',
					'label'         => 'Phone:',
					'value'         => $shipping_phone,
					'wrapper_class' => 'form-field-wide',
				)
			);

			wp_nonce_field('custom_shipping_nonce', 'custom_shipping_nonce');
			?>

		</div>
		<?php
	}

	public function wmsa_save_custom_shiiping_fields() {

		if (isset( $_POST['custom_shipping_nonce'] ) && wp_verify_nonce( sanitize_text_field(wp_unslash($_POST['custom_shipping_nonce'] ) ), 'custom_shipping_nonce') ) {
			global $post;

			$koala_em_ship = isset($_POST['shipping_em']) ? sanitize_text_field($_POST['shipping_em']) : '';
			$koala_ph_ship = isset($_POST['shipping_ph']) ? sanitize_text_field($_POST['shipping_ph']) : '';

			update_post_meta($post->ID, '_shipping_phone', wc_clean($koala_ph_ship));
			update_post_meta($post->ID, '_shipping_email', wc_clean($koala_em_ship));
		}
	}

	public function add_submenu_woocommerce() {
		add_submenu_page(
			'woocommerce', // parent slug.
			'Multiple Address Settings', // Page title.
			esc_html__('Multiple Addresses', 'koala-multiple-customer-addresses'), // Title.
			'manage_options', // Capability.
			'multiple-addresses', // slug url.
			array( $this, 'my_addresses_settings_callback' )
		); // Callback.
	}

	public function multiple_address_add_setting_files() {

		if (!get_option('load_more_text_color_setting')) {
			update_option('load_more_text_color_setting', '#FFFFFF');
		}

		if (!get_option('load_more_background_color_setting')) {
			update_option('load_more_background_color_setting', '#000000');
		}

		if (!get_option('text_color_add_address_checkout')) {
			update_option('text_color_add_address_checkout', '#000000');
		}

		include_once WMSA_PLUGIN_DIR . 'includes/settings/koala-wmsa-general_setting.php';
		include_once WMSA_PLUGIN_DIR . 'includes/settings/koala-wmsa-billing-setting.php';
		include_once WMSA_PLUGIN_DIR . 'includes/settings/koala-wmsa-shipping-setting.php';
		include_once WMSA_PLUGIN_DIR . 'includes/settings/koala-wmsa-shipping-to-multiple-address.php';
	}

	public function my_addresses_settings_callback() {
		// Determine the active tab
		$active_tab = isset($_GET['tab']) ? sanitize_text_field($_GET['tab']) : 'custom-setting';

		?>
		<div class="Multiple_Customer_Addresses_Options">
		   <div class="wrap woocommerce">
			   <h2><?php echo esc_html__('Multiple Customer Addresses Options', 'koala-multiple-customer-addresses'); ?></h2>

				<?php settings_errors(); ?>

				<h2 class="nav-tab-wrapper">
					<a href="
					<?php
					echo esc_url(add_query_arg(array(
						'page' => 'multiple-addresses',
						'tab' => 'custom-setting',
					), admin_url('admin.php')));
					?>
								" class="nav-tab <?php echo esc_attr($active_tab) === 'custom-setting' ? 'nav-tab-active' : ''; ?>">
						<?php echo esc_html__('Custom Saved Addresses', 'koala-multiple-customer-addresses'); ?>
					</a>
					<a href="
					<?php
					echo esc_url(add_query_arg(array(
						'page' => 'multiple-addresses',
						'tab' => 'shipping-multiple-address',
					), admin_url('admin.php')));
					?>
								" class="nav-tab <?php echo esc_attr($active_tab) === 'shipping-multiple-address' ? 'nav-tab-active' : ''; ?>">
						<?php echo esc_html__('Shipping to Multiple Addresses', 'koala-multiple-customer-addresses'); ?>
					</a>
				</h2>

				<?php
				if ('custom-setting' === $active_tab) {
					$sections = array(
						'general'  => __('General', 'woocommerce'),
						'billing'  => __('Billing', 'woocommerce'),
						'shipping' => __('Shipping', 'woocommerce'),
					);

					$current_section = isset($_GET['section']) ? sanitize_text_field(wp_unslash($_GET['section'])) : 'general';

					echo '<ul class="subsubsub">';
					$keys = array_keys($sections); // For compatibility
					foreach ($sections as $id => $value) {
						$class = ( sanitize_title($id) === sanitize_title($current_section) ) ? 'current' : '';
						echo '<li><a id="tab-' . esc_attr(sanitize_title($id)) . '" href="' . esc_url(add_query_arg(array(
							'page'      => 'multiple-addresses',
							'tab'       => 'custom-setting',
							'section'   => sanitize_title($id),
						), admin_url('admin.php'))) . '" class="' . esc_attr($class) . '">' . esc_html($value) . '</a></li>';
						if (end($keys) !== $id) {
							echo ' | ';
						}
					}
					echo '</ul><br class="clear" />';
				}
				?>

			</div>

			<form method="post" action="options.php" class="afacr_options_form">
				<?php
				if ('shipping-multiple-address' === $active_tab) {
					settings_fields('shipping-multiple-page');
					do_settings_sections('shipping_multiple_settings');
					submit_button();
				} elseif ('custom-setting' === $active_tab) {
					if ('general' === $current_section) {
						settings_fields('setting-page');
						do_settings_sections('general_settings');
					} elseif ('billing' === $current_section) {
						settings_fields('billing-page');
						do_settings_sections('billing_settings');
					} elseif ('shipping' === $current_section) {
						settings_fields('shipping-page');
						do_settings_sections('shipping_settings');
					}
					submit_button();
				}
				?>
			</form>
		</div>
		<?php
	}
}

new Koala_WMSA_Admin();
