<?php

defined('ABSPATH') || exit;

if (!class_exists('Koala_WSMA_User_Order') ) {

	class Koala_WSMA_User_Order {

		public function __construct() {

			add_action('edit_user_profile', array( $this, 'koala_multi_addresses_admin_fields' ), 100);

			add_action('admin_enqueue_scripts', array( $this, 'enqueue_scripts' ));

			add_filter('manage_edit-shop_order_columns', array( $this, 'kmsa_oder_menu_register_column' ));
			add_action('manage_shop_order_posts_custom_column', array( $this, 'kmsa_order_menu_content' ));
		}

		public function kmsa_oder_menu_register_column( $columns ) {

			unset($columns['order_total']);
			$columns['kmsa_billing_address']  = __('Billing', 'koala-multiple-customer-addresses');
			$columns['kmsa_shipping_address'] = __('Ship to', 'koala-multiple-customer-addresses');
			$columns['order_total']           = __('Total', 'koala-multiple-customer-addresses');
			$columns['order_actions']         = __('Actions', 'koala-multiple-customer-addresses');

			return $columns;
		}

		public function kmsa_order_menu_content( $column ) {

			global $post;

			if ('kmsa_billing_address' === $column) {
				$billing_fname          = get_post_meta($post->ID, '_billing_first_name', true);
				$billing_lname          = get_post_meta($post->ID, '_billing_last_name', true);
				$billing_fullname       = $billing_fname;
				$billing_company        = get_post_meta($post->ID, '_billing_company', true);
				$billing_ad1            = get_post_meta($post->ID, '_billing_address_1', true);
				$billing_ad2            = get_post_meta($post->ID, '_billing_address_2', true);
				$billing_city           = get_post_meta($post->ID, '_billing_city', true);
				$billing_state          = get_post_meta($post->ID, '_billing_state', true);
				$billing_postcode       = get_post_meta($post->ID, '_billing_postcode', true);
				$billing_country        = get_post_meta($post->ID, '_billing_country', true);
				$billing_payment_method = get_post_meta($post->ID, '_payment_method_title', true);
				echo esc_attr($billing_fullname . ',' . $billing_company . ',' . $billing_city . ',' . $billing_state . ',' . $billing_postcode . ',' . $billing_country);
				echo '<br>';
			}

			if ('kmsa_shipping_address' === $column) {
				$shipping_fname    = get_post_meta($post->ID, '_shipping_first_name', true);
				$shipping_lname    = get_post_meta($post->ID, '_shipping_last_name', true);
				$shipping_fullname = $shipping_fname;
				$shipping_company  = get_post_meta($post->ID, '_shipping_company', true);
				$shipping_ad1      = get_post_meta($post->ID, '_shipping_address_1', true);
				$shipping_ad2      = get_post_meta($post->ID, '_shipping_address_2', true);
				$shipping_city     = get_post_meta($post->ID, '_shipping_city', true);
				$shipping_postcode = get_post_meta($post->ID, '_shipping_postcode', true);
				$shipping_country  = get_post_meta($post->ID, '_shipping_country', true);
				$shipping_state    = get_post_meta($post->ID, '_shipping_state', true);
				?>
				<a target="_blank" href="http://maps.google.com/?q=<?php echo esc_attr($shipping_ad1 . '&nbsp' . $shipping_ad2); ?>">
					<?php
					echo esc_attr($shipping_fullname . ',' . $shipping_company . ',' . $shipping_city . ',' . $shipping_state . ',' . $shipping_postcode . ',' . $shipping_country);
					?>
				</a>
				<?php
			}

			if ('order_actions' === $column) {
				$order_id     = $post->ID;
				$order        = new WC_Order($order_id);
				$order_status = $order->get_status();
				if ('on-hold' == $order_status || 'pending' == $order_status) {
					?>
					<div class="order_status">
						<input type="hidden" name="order_id" id="order_status" value="<?php echo esc_attr($order_id); ?>">
						<button type="button" class="processing fa" title="processing"><i class="far fa-spinner"></i></button>
						<button type="button" class="completed fa" title="completed"><i class="far fa-check-circle"></i></button>
					</div>
					<?php
				} elseif ('processing' == $order_status) {
					?>
					<div class="order_status">
						<input type="hidden" name="order_id" id="order_status" value="<?php echo esc_attr($order_id); ?>">
						<button type="button" class="completed fa" title="completed"><i class="far fa-check-circle"></i></button>
					</div>
					<?php
				}
			}
		}

		public function enqueue_scripts() {

			wp_enqueue_style('Font-Awesome', 'https://maxcdn.bootstrapcdn.com/font-awesome/4.4.0/css/font-awesome.min.css', false, '1.0.0');
			wp_enqueue_script('admin-billing-form', WMSA_URL . 'assets/js/koala_multiple_addresses_billingform.js', array( 'jquery' ), '1.0.0', true);
			wp_enqueue_script('admin-ship-form', WMSA_URL . 'assets/js/koala_multiple_addresses_shippingform.js', array( 'jquery' ), '1.0.0', true);
			wp_enqueue_script('ka-select2', WMSA_URL . 'assets/js/select2.js', array( 'jquery' ), '1.0.0', true);

			wp_register_style('my_css', WMSA_URL . 'assets/css/koala_multiple_addresses_billing.css', false, '1.0.0');
			wp_enqueue_style('my_css');
			wp_register_style('my_css3', WMSA_URL . 'assets/css/select2.css', false, '1.0.0');
			wp_enqueue_style('my_css3');
			wp_register_style('admin_user_css', WMSA_URL . 'assets/css/koala_ma_admin.css', false, '1.0.0');
			wp_enqueue_style('admin_user_css');

			$koala_multi_address_ajax_data = array(
				'admin_url' => admin_url('admin-ajax.php'),
				'nonce'     => wp_create_nonce('multi_address_nonce_admin'),
			);
			wp_localize_script('admin-ship-form', 'koala_multi_country', $koala_multi_address_ajax_data);
			wp_localize_script('admin-billing-form', 'koala_multi_country', $koala_multi_address_ajax_data);
		}

		public function koala_multi_addresses_admin_fields( $user ) {

			$user_id = isset($_GET['user_id']) ? sanitize_text_field($_GET['user_id']) : '';
			?>
			<h4><?php esc_html_e('Additional Addresses', 'koala-multiple-customer-addresses'); ?> </h4>
			<div id="add_button_refresh">
				<?php
				$get_val = get_option('enable_disable_billing');
				if ('1' !== $get_val) {
					$max_addresses = get_option('max_num_billing');
					if (!empty($max_addresses) && 0 !== $max_addresses) {
						$all_shiiping_add = get_user_meta($user_id, 'all_billing_address', true);
						$count            = 0;
						if (!empty($all_shiiping_add)) {
							foreach ($all_shiiping_add as $key_b => $value) {
								++$count;
							}
						}
						if ($count < $max_addresses) {
							$billing_label = get_option('billing_title_key_field');
							if (empty($billing_label)) {
								$billing_title = 'Add New Billing Address';
							} else {
								$billing_title = $billing_label;
							}
							?>
							<input id="myBtn" class="buttonstyle1" type="button" value="<?php echo esc_attr($billing_title); ?>">
							<?php
						}

					} else {
						$billing_label = get_option('billing_title_key_field');
						if (empty($billing_label)) {
							$billing_title = 'Add New Billing Address';
						} else {
							$billing_title = $billing_label;
						}
						?>
						<input id="myBtn" class="buttonstyle1" type="button" value="<?php echo esc_attr($billing_title); ?>">
						<?php
					}
				}
				$disable_shipping = get_option('enable_disable_shipping');
				if ('1' !== $disable_shipping) {
					$max_addresses_shipping = get_option('max_num_shipping');
					if (!empty($max_addresses_shipping) && 0 !== $max_addresses_shipping) {
						$all_shiiping_add = get_user_meta($user_id, 'all_shipping_address', true);
						$count            = 0;
						if (!empty($all_shiiping_add)) {
							foreach ($all_shiiping_add as $key_t => $value) {
								++$count;
							}
						}
						if ($count < $max_addresses_shipping) {
							$shipping_label = get_option('shipping_title_key_field');
							if (empty($shipping_label)) {
								$shipping_title = 'Add New Shipping Address';
							} else {
								$shipping_title = $shipping_label;
							}
							?>
							<input id="myBtn1" type="button" class="buttonstyle1" value="<?php echo esc_attr($shipping_title); ?>">
							<?php
						}
					} else {
						$shipping_label = get_option('shipping_title_key_field');
						if (empty($shipping_label)) {
							$shipping_title = 'Add New Shipping Address';
						} else {
							$shipping_title = $shipping_label;
						}
						?>
						<input id="myBtn1" type="button" class="buttonstyle1" value="<?php echo esc_attr($shipping_title); ?>">
						<?php
					}
				}
				?>
			</div>
			<body1>
				<div id="myModal" class="modal">
					<div class="modal-content">
						<span class="close">&times;</span>
						<div class="message_billing_admin"></div>
						<?php
						$getidentifier = get_option('disable_identifier_name');
						if ('1' !== $getidentifier) {
							?>
							<div class="wms-row">
								<div class="wms-col-12">
									<label class="mylabel"><?php esc_html_e('Identifier / Name', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
									<input placeholder="(Examples: 'Office address,' 'Mary Jones,' 'MJ 2145,' etc.)" class="inputsize" type="text" name="identifier_name_billing">
								</div>
							</div>
							<?php
						}
						?>
						<div class="wms-row">
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('First Name', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input type="text" name="first_name_billing">
							</div>

							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Last Name', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input type="text" name="last_name_billing">
							</div>
						</div>
						<input type="hidden" name="user_id" value="<?php echo esc_attr($user_id); ?>">
						<?php
						$require_company_billing = get_option('require_company_field_billing');
						if ('1' === $require_company_billing) {
							?>
							<div class="wms-row">
								<div class="wms-col-12">
									<label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
									<input class="inputsize" type="text" name="copmany_name_billing_required">
								</div>
							</div>
							<?php
						} else {
							?>
							<div class="wms-row">
								<div class="wms-col-12">
									<label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?></label>
									<input class="inputsize" type="text" name="copmany_name_billing">
								</div>
							</div>
							<?php
						}
						?>
						<div class="wms-row">
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Choose Country', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								<select name="country_name_billing" id="cor_countries_billing">
									<?php
									$countr_obj = new WC_Countries();
									$countries  = $countr_obj->__get('countries');
									foreach ($countries as $key => $country) {
										?>
										<option value="<?php echo esc_html($key); ?>">
											<?php echo esc_html__($country, 'koala-multiple-customer-addresses'); ?>
										</option>
										<?php
									}
									?>
								</select>
							</div>
							<div class="wms-col-6">
								<div class="state_val_add_billing">
								</div>
							</div>
						</div>
						<div class="wms-row">
							<div class="wms-col-12">
								<label class="mylabel"><?php esc_html_e('Street Address', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input placeholder="House number and street number" type="text" class="inputsize" name="st_address_billing">
							</div>
						</div>
						<div class="wms-row">
							<div class="wms-col-12">
								<input placeholder="Apartment, suite, unit, etc. (optional)" type="text" class="inputsize address_margin" name="st_address_billing2">
							</div>
						</div>
						<div class="wms-row">
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Town/City', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input class="inputsize" type="text" name="town_address_billing" placeholder="">
							</div>
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Postal code', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input class="inputsize" type="text" name="postal_code_billing" placeholder="">
							</div>
						</div>
						<div class="wms-row">
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Phone', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input class="inputsize" type="number" name="phone_billing" placeholder="">
							</div>
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Email Address', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input class="inputsize" type="Email" name="email_billing" placeholder="">
							</div>
						</div>
						<div class="wms-row">
							<div class="wms-col-12">
								<div align="right"><input type="button" class="buttonstyle billing_form_submit" name="billing_form_submit" value="Save"></div>
							</div>
						</div>
					</div>

				</div>
				<div id="myModal1" class="modal1">
					<div class="modal-content1">
						<span class="close1">&times;</span>
						<div class="message_shipping_edit_admin"></div>
						<?php
						$getidentifier = get_option('disable_identifier_name');
						if ('1' !== $getidentifier) {
							?>
							<div class="wms-row">
								<div class="wms-col-12">
									<label class="mylabel"><?php esc_html_e('Identifier / Name', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
									<input placeholder="(Examples: 'Office address,' 'Mary Jones,' 'MJ 2145,' etc.)" class="inputsize" type="text" name="identifier_name_shipping">
								</div>
							</div>
							<?php
						}
						?>
						<div class="wms-row">
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('First Name', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input type="text" name="first_name_shipping">
							</div>
							<div class="wms-col-6">
								<input type="hidden" name="user_id" value="<?php echo esc_attr($user_id); ?>">
								<label class="mylabel"><?php esc_html_e('Last Name', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input type="text" name="last_name_shipping">
							</div>
						</div>
						<?php
						$require_company_shipping = get_option('require_company_field_shipping');
						if ('1' === $require_company_shipping) {
							?>
							<div class="wms-row">
								<div class="wms-col-12">
									<label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span><br>
									<input class="inputsize" type="text" name="copmany_name_shipping_required">
								</div>
							</div>
							<?php
						} else {
							?>
							<div class="wms-row">
								<div class="wms-col-12">
									<label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?></label>
									<input class="inputsize" type="text" name="copmany_name_shipping">
								</div>
							</div>
							<?php
						}
						?>
						<div class="wms-row">
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Choose Country', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label><br>

								<select name="country_name_shipping" id="cor_countries_shipping">

									<?php
									$countr_obj = new WC_Countries();
									$countries  = $countr_obj->__get('countries');
									foreach ($countries as $key => $country) {
										?>
										<option value="<?php echo esc_html($key); ?>">
											<?php echo esc_html__($country, 'koala-multiple-customer-addresses'); ?>
										</option>
										<?php
									}
									?>
								</select>
							</div>
							<div class="wms-col-6">
								<div class="state_val_add_shipping">
								</div>
							</div>
						</div>
						<div class="wms-row">
							<div class="wms-col-12">
								<label class="mylabel"><?php esc_html_e('Street Address', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input type="text" placeholder="House number and street number" class="inputsize" name="st_address_shipping">
							</div>
						</div>
						<div class="wms-row">
							<div class="wms-col-12">
								<input placeholder="Apartment, suite, unit, etc. (optional)" type="text" class="inputsize address_margin" name="st_address_shipping2">
							</div>
						</div>
						<div class="wms-row">
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Town/City', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input class="inputsize" type="text" name="town_address_shipping" placeholder="">
							</div>
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Postal code', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input class="inputsize" type="text" name="pin_code_shipping" placeholder="">
							</div>
						</div>
						<?php
						$add_shipping_phone = get_option('add_shipping_phone_option');
						?>
						<div class="wms-row">
							<?php
							if ('1' === $add_shipping_phone) {
								$require_phone = get_option('require_shipping_phone');
								if ('1' === $require_phone) {
									?>
									<div class="wms-col-6">
										<label class="mylabel"><?php esc_html_e('Phone', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>

										<input class="inputsize" type="number" name="phone_shipping_required" placeholder="">
									</div>
									<?php
								} else {
									?>
									<div class="wms-col-6">
										<label class="mylabel"><?php esc_html_e('Phone', 'koala-multiple-customer-addresses'); ?></label>
										<input class="inputsize" type="number" name="phone_shipping" placeholder="">
									</div>
									<?php
								}
							}
							?>

							<?php
							$add_shipping_email = get_option('add_shipping_email_option');
							if ('1' === $add_shipping_email) {
								$require_email = get_option('require_shipping_email');
								if ('1' === $require_email) {
									?>
									<div class="wms-col-6">
										<label class="mylabel"><?php esc_html_e('Email Address', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
										<input class="inputsize" type="Email" name="email_shipping_required" placeholder="">
									</div>
									<?php
								} else {
									?>
									<div class="wms-col-6">
										<label class="mylabel"><?php esc_html_e('Email Address', 'koala-multiple-customer-addresses'); ?></label>
										<input class="inputsize" type="Email" name="email_shipping" placeholder="">
									</div>
									<?php
								}
							}
							?>
						</div>
						<div class="wms-row">
							<div class="wms-col-12">
								<div align="right"><input type="button" class="buttonstyle save shipping_form_submit" name="shipping_form_submit" value="Save"></div>
							</div>
						</div>
					</div>
				</div>
				<div id="myModal2" class="modal2">
					<div class="modal-content2">
						<span class="close2">&times;</span>
						<div class="message_shipping_admin"></div>
						<?php
						$getidentifier = get_option('disable_identifier_name');
						if ('1' !== $getidentifier) {
							?>
							<div class="wms-row">
								<div class="wms-col-12">
									<label class="mylabel"><?php esc_html_e('Identifier / Name', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span><br>
									<input placeholder="(Examples: 'Office address,' 'Mary Jones,' 'MJ 2145,' etc.)" class="inputsize" type="text" id="identifier_name_shipping_edit" name="identifier_name_shipping_edit">
								</div>
							</div>
							<?php
						} else {
							?>
							<div class="wms-row">
								<div class="wms-col-12">
									<input class="inputsize" type="hidden" id="identifier_name_shipping_edit" name="identifier_name_shipping_edit_hidden">
								</div>
							</div>
							<?php
						}
						?>
						<div class="wms-row">
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('First Name', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input class="inputsize" type="text" name="first_name_shipping_edit" id="first_name_shipping_edit">
							</div>
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Last Name', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input class="inputsize" type="text" id="last_name_shipping_edit" name="last_name_shipping_edit">
							</div>
						</div>
						<?php
						$require_company_shipping = get_option('require_company_field_shipping');
						if ('1' === $require_company_shipping) {
							?>
							<div class="wms-row">
								<div class="wms-col-12">
									<label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span><br>
									<input class="inputsize" type="text" id="copmany_name_shipping_edit_required" name="copmany_name_shipping_edit_required">
								</div>
							</div>
							<?php
						} else {
							?>
							<div class="wms-row">
								<div class="wms-col-12">
									<label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?></label>
									<input class="inputsize" type="text" id="copmany_name_shipping_edit" name="copmany_name_shipping_edit">
								</div>
							</div>
							<?php
						}
						?>
						<input type="hidden" name="user_id" value="<?php echo esc_attr($user_id); ?>">
						<div class="wms-row">
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Choose Country', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								<input type="hidden" name="shipping_country1" id="country_shipping111">
								<select name="country_name_shipping_edit" class="country_name_shipping_edit" id="country_name_shipping_edit">
									<?php
									$countr_obj = new WC_Countries();
									$countries  = $countr_obj->__get('countries');
									foreach ($countries as $key => $country) {
										?>
										<option id=abc value="<?php echo esc_html($key); ?>">
											<?php echo esc_html__($country, 'koala-multiple-customer-addresses'); ?>
										</option>
										<?php
									}
									?>
								</select>
								<input type="hidden" name="edit_id_shipping" id="shipping_edit_id">
							</div>
							<div class="wms-col-6">
								<div name="testing_shipping" id="state_val_edit_shipping">
								</div>
							</div>
						</div>
						<div class="wms-row">
							<div class="wms-col-12">
								<label class="mylabel"><?php esc_html_e('Street Address', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input placeholder="House number and street number" type="text" class="inputsize" id="st_address_shipping_edit" name="st_address_shipping_edit">
							</div>
						</div>
						<div class="wms-row">
							<div class="wms-col-12">
								<input placeholder="Apartment, suite, unit, etc. (optional)" type="text" class="inputsize address_margin" id="st_address_shipping_edit2" name="st_address_shipping_edit2">
							</div>
						</div>
						<div class="wms-row">
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Town/City', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input class="inputsize" type="text" id="town_address_shipping_edit" name="town_address_shipping_edit" placeholder="">
							</div>
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Postal code', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input class="inputsize" type="text" id="pin_code_shipping_edit" name="pin_code_shipping_edit" placeholder="">
							</div>
						</div>
						<?php
						$add_shipping_phone = get_option('add_shipping_phone_option');
						?>
						<div class="wms-row">

							<?php
							if ('1' === $add_shipping_phone) {
								$require_phone = get_option('require_shipping_phone');
								if ('1' === $require_phone) {
									?>
									<div class="wms-col-6">
										<label class="mylabel"><?php esc_html_e('Phone', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
										<input class="inputsize" type="number" name="phone_shipping_edit_required" id="phone_shipping_edit_required" placeholder="">
									</div>
									<?php
								} else {
									?>
									<div class="wms-col-6">
										<label class="mylabel"><?php esc_html_e('Phone', 'koala-multiple-customer-addresses'); ?></label>
										<input class="inputsize" type="number" name="phone_shipping_edit" id="phone_shipping_edit" placeholder="">
									</div>
									<?php
								}
							}
							?>
							<?php
							$add_shipping_email = get_option('add_shipping_email_option');
							if ('1' === $add_shipping_email) {
								$require_email = get_option('require_shipping_email');
								if ('1' === $require_email) {
									?>
									<div class="wms-col-6">
										<label class="mylabel"><?php esc_html_e('Email Address', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
										<input class="inputsize" type="Email" name="email_shipping_edit_required" id="email_shipping_edit_required" placeholder="">
									</div>
									<?php
								} else {
									?>
									<div class="wms-col-6">
										<label class="mylabel"><?php esc_html_e('Email Address', 'koala-multiple-customer-addresses'); ?></label>
										<input class="inputsize" type="Email" name="email_shipping_edit" id="email_shipping_edit" placeholder="">
									</div>
									<?php
								}
							}
							?>
						</div>
						<div class="wms-row">
							<div class="wms-col-12">
								<div align="right"><input type="button" class="shipping_form_edit buttonstyle" name="shipping_form_edit" value="Save"></div>
							</div>
						</div>
					</div>
				</div>
				<div id="myModal3" class="modal3">
					<div class="modal-content3">
						<span class="close3">&times;</span>
						<div class="message_billing_edit_admin"></div>
						<?php
						$getidentifier = get_option('disable_identifier_name');
						if ('1' !== $getidentifier) {
							?>
							<div class="wms-row">
								<div class="wms-col-12">
									<label class="mylabel"><?php esc_html_e('Identifier / Name', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
									<input type="hidden" name="edit_id_billing" id="billing_edit_id">
									<input placeholder="(Examples: 'Office address,' 'Mary Jones,' 'MJ 2145,' etc.)" class="inputsize" type="text" id="identifier_name_billing_edit" name="identifier_name_billing_edit">
								</div>
							</div>
							<?php
						} else {
							?>
							<div class="wms-row">
								<div class="wms-col-12">
									<input type="hidden" name="edit_id_billing" id="billing_edit_id">
									<input class="inputsize" type="hidden" id="identifier_name_billing_edit" name="identifier_name_billing_edit_hidden">
								</div>
							</div>
							<?php
						}
						?>
						<div class="wms-row">
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('First Name', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input type="text" name="first_name_billing_edit" id="first_name_billing_edit">
							</div>
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Last Name', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input type="text" id="last_name_billing_edit" name="last_name_billing_edit">
							</div>
						</div>
						<?php
						$require_company_billing = get_option('require_company_field_billing');
						if ('1' === $require_company_billing) {
							?>
							<div class="wms-row">
								<div class="wms-col-12">
									<label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
									<input class="inputsize" type="text" id="copmany_name_billing_edit_required" name="copmany_name_billing_edit_required">
								</div>
							</div>
							<?php
						} else {

							?>
							<div class="wms-row">
								<div class="wms-col-12">
									<label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?></label>
									<input class="inputsize" type="text" id="copmany_name_billing_edit" name="copmany_name_billing_edit">
								</div>
							</div>
							<?php
						}
						?>
						<div class="wms-row">
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Choose Country', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								<input type="hidden" name="user_id" value="<?php echo esc_attr($user_id); ?>">
								<input type="hidden" name="billing_country1" id="billing_shipping111">
								<select name="country_name_billing_edit" id="country_name_billing_edit" class="country_name_billing_edit">
									<?php
									$countr_obj = new WC_Countries();
									$countries  = $countr_obj->__get('countries');
									foreach ($countries as $key => $country) {
										?>
										<option value="<?php echo esc_html($key); ?>">
											<?php echo esc_html__($country, 'koala-multiple-customer-addresses'); ?>
										</option>
										<?php
									}
									?>
								</select>
								<input type="hidden" name="edit_id" id="shipping_edit_id">
							</div>
							<div class="wms-col-6">
								<div id="state_val_edit_billing">
								</div>
							</div>
						</div>
						<div class="wms-row">
							<div class="wms-col-12">
								<label class="mylabel"><?php esc_html_e('Street Address', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input placeholder="House number and street number" type="text" class="inputsize" id="st_address_billing_edit" name="st_address_billing_edit">
							</div>
						</div>
						<div class="wms-row">
							<div class="wms-col-12">
								<input placeholder="Apartment, suite, unit, etc. (optional)" type="text" class="inputsize address_margin" id="st_address_billing_edit2" name="st_address_billing_edit2">
							</div>
						</div>
						<div class="wms-row">
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Town/City', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input class="inputsize" type="text" id="town_address_billing_edit" name="town_address_billing_edit" placeholder="">
							</div>

							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Postal code', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input class="inputsize" type="text" id="postal_code_billing_edit" name="postal_code_billing_edit" placeholder="">
							</div>
						</div>
						<div class="wms-row">
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Phone', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input class="inputsize" type="number" id="phone_billing_edit" name="phone_billing_edit" placeholder="">
							</div>
							<div class="wms-col-6">
								<label class="mylabel"><?php esc_html_e('Email Address', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
								<input class="inputsize" type="Email" id="email_billing_edit" name="email_billing_edit" placeholder="">
							</div>
						</div>
						<div class="wms-row">
							<div class="wms-col-12"><input type="button" class="billing_form_edit buttonstyle" name="billing_form_edit" value="Save"></div>
						</div>
					</div>
				</div>
			</body1>
			<?php
			$disable_shipping = get_option('enable_disable_shipping');
			if ('1' !== $disable_shipping) {
				?>
				<div id="table_arc" class="table_arc" width="100%">
					<tbody>
						<h3><?php esc_html_e('Shipping Addresses', 'koala-multiple-customer-addresses'); ?></h3>
						<?php
						$all_shiiping_add = get_user_meta($user_id, 'all_shipping_address', true); ////dont mess
						?>
						<ul class="delcheck table_row">
							<?php
							if (!empty($all_shiiping_add)) {
								foreach ($all_shiiping_add as $key => $af_role_his) {
									?>

									<li class="table_data">
										<h5>
											<?php $radio_state_shipping = get_user_meta($user_id, 'default_shipping_meta', true); ?>
											<input type="hidden" name="user_id" value="<?php echo esc_attr($user_id); ?>">
											<input type="hidden" name="idname" value="<?php echo esc_attr($af_role_his['address_identifier_shipping']); ?>">
											<input type="hidden" name="key" value="<?php echo esc_attr($key); ?>">
											<?php
											$address_label = get_option('default_address_key_field');
											?>
											<input type="radio" class="default_shipping_address radio_testing" name="default_shipping_meta" value="<?php echo esc_attr($key); ?>" <?php checked($radio_state_shipping, $key); ?>>
											<?php
											if (!empty($address_label)) {
												echo esc_attr($address_label);
											} else {
												?>
												<?php esc_html_e('Set Default Address', 'koala-multiple-customer-addresses'); ?>
												<?php
											}
											?>
										</h5>
										<?php
										$max_addresses_shipping = get_option('max_num_shipping');
										if (!empty($max_addresses_shipping) && 0 !== $max_addresses_shipping) {
											$all_shiiping_add = get_user_meta($user_id, 'all_shipping_address', true);
											$count            = 0;
											foreach ($all_shiiping_add as $key_t => $value) {
												++$count;
											}
											if ($count < $max_addresses_shipping) {
												?>
												<button type="button" name="duplicate_shipping" class="duplicate_shipping action_buttons_style" value="<?php echo esc_attr($key); ?>"><?php esc_html_e('Duplicate', 'koala-multiple-customer-addresses'); ?></button>
												<?php
											}
										} else {
											?>
											<button type="button" name="duplicate_shipping" class="duplicate_shipping action_buttons_style" value="<?php echo esc_attr($key); ?>"><?php esc_html_e('Duplicate', 'koala-multiple-customer-addresses'); ?></button>
											<?php
										}
										?>
										<button type="button" class="shipping_edit_c action_buttons_style" id="shipping_edit" name="edit_shippings" value="<?php echo esc_attr($key); ?>">
											<?php esc_html_e('Edit', 'koala-multiple-customer-addresses'); ?></button>
										<input type="hidden" name="user_id" value="<?php echo esc_attr($user_id); ?>">
										<button type="button" class="delete_address_shipping action_buttons_style" name="delete_address_shipping" value="<?php echo esc_attr($key); ?>">
											<?php esc_html_e('Delete', 'koala-multiple-customer-addresses'); ?></button>

										<?php
										$address_size = get_option('address_title_tag_key_field');
										?>
										<<?php echo esc_attr($address_size); ?>>
											<?php echo esc_attr($af_role_his['address_identifier_shipping']); ?>
										</<?php echo esc_attr($address_size); ?>>
										<input type="hidden" name="address_id" value=" <?php echo esc_attr($af_role_his['address_identifier_shipping']); ?>">
										<label class="viewlables"><?php esc_html_e('Name', 'koala-multiple-customer-addresses'); ?></label>
										<input type="hidden" name="first_name" value=" <?php echo esc_attr($af_role_his['first_name_shipping']); ?>">
										<input type="hidden" name="last_name" value=" <?php echo esc_attr($af_role_his['last_name_shipping']); ?>">
										<?php echo esc_attr($af_role_his['first_name_shipping']); ?>
										<?php echo esc_attr($af_role_his['last_name_shipping']); ?>
										<label class="viewlables">Company Name</label>
										<?php echo esc_attr($af_role_his['copmany_name_shipping']); ?>
										<input type="hidden" name="company_name" value=" <?php echo esc_attr($af_role_his['copmany_name_shipping']); ?>">
										<label class="viewlables"><?php esc_html_e('Country', 'koala-multiple-customer-addresses'); ?></label>
										<?php
										$country_decoded_name = $af_role_his['country_name_shipping'];
										$countr_obj           = new WC_Countries();
										$countries            = $countr_obj->__get('countries');
										?>
										<input type="hidden" name="country_code_shipping_hidden" value="<?php echo esc_html__($country_decoded_name, 'koala-multiple-customer-addresses'); ?>">
										<?php
										foreach ($countries as $key => $country) {
											if ($key == $country_decoded_name) {
												echo esc_html__($country, 'koala-multiple-customer-addresses');
												?>
												<input type="hidden" name="country_name_shipping_hidden" value="<?php echo esc_html__($country, 'koala-multiple-customer-addresses'); ?>">
												<?php
											}
										}
										?>

										<label class="viewlables"><?php esc_html_e('State', 'koala-multiple-customer-addresses'); ?></label>
										<?php echo esc_attr($af_role_his['country_state_shipping']); ?>
										<label class="viewlables"><?php esc_html_e('Street Address', 'koala-multiple-customer-addresses'); ?></label>
										<input type="hidden" name="street_name" value=" <?php echo esc_attr($af_role_his['street_address_shipping']); ?>">
										<input type="hidden" name="street_name2" value=" <?php echo esc_attr($af_role_his['street_address_shipping2']); ?>">
										<?php echo esc_attr($af_role_his['street_address_shipping']); ?>
										<?php echo esc_attr($af_role_his['street_address_shipping2']); ?>
										<label class="viewlables"><?php esc_html_e('Town/City', 'koala-multiple-customer-addresses'); ?></label>
										<input type="hidden" name="town_name" value=" <?php echo esc_attr($af_role_his['town_address_shipping']); ?>">
										<?php echo esc_attr($af_role_his['town_address_shipping']); ?>
										<label class="viewlables"><?php esc_html_e('Postal Code', 'koala-multiple-customer-addresses'); ?></label>
										<input type="hidden" name="pin_name" value=" <?php echo esc_attr($af_role_his['pin_code_shipping']); ?>">
										<?php echo esc_attr($af_role_his['pin_code_shipping']); ?>
										<?php
										$add_shipping_phone = get_option('add_shipping_phone_option');
										if ('1' === $add_shipping_phone) {
											?>
											<label class="viewlables"><?php esc_html_e('Phone', 'koala-multiple-customer-addresses'); ?></label>
											<input type="hidden" name="phone_name_shipping" value=" <?php echo esc_attr($af_role_his['phone_shipping']); ?>">
											<?php echo esc_attr($af_role_his['phone_shipping']); ?>
											<?php
										} else {
											?>
											<input type="hidden" name="phone_name_shipping">
											<?php
										}
										?>
										<?php
										$add_shipping_email = get_option('add_shipping_email_option');
										if ('1' === $add_shipping_email) {
											?>
											<label class="viewlables"><?php esc_html_e('email', 'koala-multiple-customer-addresses'); ?></label>
											<input type="hidden" name="email_name_shipping" value=" <?php echo esc_attr($af_role_his['email_shipping']); ?>">
											<?php echo esc_attr($af_role_his['email_shipping']); ?>
											<?php
										} else {
											?>
											<input type="hidden" name="email_name_shipping">
											<?php
										}
										?>
									</li>


									<?php
								}
							} else {
								?>
								<li colspan="4"><?php esc_html_e('No address found', 'koala-multiple-customer-addresses'); ?></li>
								<?php
							}
							?>
						</ul>
					</tbody>
				</div>
				<?php
			}
			?>
			<?php
			$get_val = get_option('enable_disable_billing');
			if ('1' !== $get_val) {
				?>
				<div class="table_arc" id="table_arc_billing" width="100%">
					<tbody>
						<h3><?php esc_html_e('Billing Addresses', 'koala-multiple-customer-addresses'); ?></h3>
						<ul class="billing_edit table_row">
							<?php
							$all_shiiping_add = get_user_meta($user_id, 'all_billing_address', true);
							if (!empty($all_shiiping_add)) {
								foreach ($all_shiiping_add as $key => $af_role_his) {
									?>
									<li class="table_data">
										<h5>
											<?php $radio_state = get_user_meta($user_id, 'default_billing_meta', true); ?>
											<input type="hidden" name="user_id" value="<?php echo esc_attr($user_id); ?>">
											<input type="hidden" name="idname" value="<?php echo esc_attr($af_role_his['address_identifier_billing']); ?>">
											<input type="hidden" name="key" value="<?php echo esc_attr($key); ?>">
											<?php
											$address_label = get_option('default_address_key_field');
											?>
											<input type="radio" class="default_billing_address radio_billing" name="default_billing_meta" value="<?php echo esc_attr($key); ?>" <?php checked($radio_state, $key); ?>>
											<?php
											if (!empty($address_label)) {
												echo esc_attr($address_label);
											} else {
												?>
												<?php esc_html_e('Set Default Address', 'koala-multiple-customer-addresses'); ?>
												<?php
											}
											?>
										</h5>
										<?php
										$max_addresses = get_option('max_num_billing');
										if (!empty($max_addresses) && 0 !== $max_addresses) {
											$all_shiiping_add = get_user_meta($user_id, 'all_billing_address', true);
											$count            = 0;
											foreach ($all_shiiping_add as $key_b => $value) {
												++$count;
											}
											if ($count < $max_addresses) {
												?>
												<button type="button" name="duplicate_billing" class="duplicate_billing action_buttons_style" value="<?php echo esc_attr($key); ?>"><?php esc_html_e('Duplicate', 'koala-multiple-customer-addresses'); ?></button>
												<?php
											}
										} else {
											?>
											<button type="button" name="duplicate_billing" class="duplicate_billing action_buttons_style" value="<?php echo esc_attr($key); ?>"><?php esc_html_e('Duplicate', 'koala-multiple-customer-addresses'); ?></button>
											<?php
										}
										?>
										<button type="button" class="billing_edit_c action_buttons_style" id="billing_edit" name="edit_billings" value="<?php echo esc_attr($key); ?>">
											<?php esc_html_e('Edit', 'koala-multiple-customer-addresses'); ?></button>
										<button type="button" name="delete_address_billing" class="delete_address_billing action_buttons_style" value="<?php echo esc_attr($key); ?>">
											<?php esc_html_e('Delete', 'koala-multiple-customer-addresses'); ?>
										</button>
										<?php $address_size = get_option('address_title_tag_key_field'); ?>
										<<?php echo esc_attr($address_size); ?>>
											<?php echo esc_attr($af_role_his['address_identifier_billing']); ?>
										</<?php echo esc_attr($address_size); ?>>
										<input type="hidden" name="user_id" value="<?php echo esc_attr($user_id); ?>">
										<input type="hidden" name="identifier_name_billing_edit_hidden" value=" <?php echo esc_attr($af_role_his['address_identifier_billing']); ?>">
										<label class="viewlables"><?php esc_html_e('Name', 'koala-multiple-customer-addresses'); ?></label>
										<input type="hidden" name="first_name_billing_edit_hidden" value=" <?php echo esc_attr($af_role_his['first_name_billing']); ?>">
										<input type="hidden" name="last_name_billing_edit_hidden" value=" <?php echo esc_attr($af_role_his['last_name_billing']); ?>">
										<?php echo esc_attr($af_role_his['first_name_billing']); ?>
										<?php echo esc_attr($af_role_his['last_name_billing']); ?>
										<label class="viewlables"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?></label>
										<input type="hidden" name="copmany_name_billing_edit_hidden" value=" <?php echo esc_attr($af_role_his['copmany_name_billing']); ?>">
										<?php echo esc_attr($af_role_his['copmany_name_billing']); ?>
										<label class="viewlables"><?php esc_html_e('Country', 'koala-multiple-customer-addresses'); ?></label>
										<?php
										$country_decoded_name = $af_role_his['country_billing'];
										$countr_obj           = new WC_Countries();
										$countries            = $countr_obj->__get('countries');
										?>
										<input type="hidden" name="get_country_code_billing" value="<?php echo esc_html__($country_decoded_name, 'koala-multiple-customer-addresses'); ?>">
										<?php
										foreach ($countries as $key => $country) {
											if ($key == $country_decoded_name) {
												echo esc_html__($country, 'koala-multiple-customer-addresses');
												?>
												<input type="hidden" name="country_name_billing_hidden" value="<?php echo esc_html__($country, 'koala-multiple-customer-addresses'); ?>">
												<?php
											}
										}
										?>

										<label class="viewlables"><?php esc_html_e('State', 'koala-multiple-customer-addresses'); ?></label>
										<?php echo esc_attr($af_role_his['country_state']); ?>
										<label class="viewlables"><?php esc_html_e('Street Address', 'koala-multiple-customer-addresses'); ?></label>
										<?php echo esc_attr($af_role_his['street_address_billing']); ?>
										<?php echo esc_attr($af_role_his['street_address_billing2']); ?>
										<input type="hidden" name="street_address_billing_edit_hidden" value=" <?php echo esc_attr($af_role_his['street_address_billing']); ?>">
										<input type="hidden" name="street_address_billing_edit_hidden2" value=" <?php echo esc_attr($af_role_his['street_address_billing2']); ?>">
										<label class="viewlables"><?php esc_html_e('Town/City', 'koala-multiple-customer-addresses'); ?></label>
										<?php echo esc_attr($af_role_his['town_address_billing']); ?>
										<input type="hidden" name="town_address_billing_edit_hidden" value=" <?php echo esc_attr($af_role_his['town_address_billing']); ?>">
										<label class="viewlables"><?php esc_html_e('Postal Code', 'koala-multiple-customer-addresses'); ?></label>
										<?php echo esc_attr($af_role_his['postal_code_billing']); ?>
										<input type="hidden" name="postal_code_billing_edit_hidden" value=" <?php echo esc_attr($af_role_his['postal_code_billing']); ?>">
										<label class="viewlables"><?php esc_html_e('Phone Number', 'koala-multiple-customer-addresses'); ?></label>
										<?php echo esc_attr($af_role_his['phone_billing']); ?>
										<input type="hidden" name="phone_name_billing_edit_hidden" value=" <?php echo esc_attr($af_role_his['phone_billing']); ?>">
										<label class="viewlables"><?php esc_html_e('Email', 'koala-multiple-customer-addresses'); ?></label>
										<?php echo esc_attr($af_role_his['email_billing']); ?>
										<input type="hidden" name="email_billing_edit_hidden" value=" <?php echo esc_attr($af_role_his['email_billing']); ?>">
									</li>
									<?php
								}
							} else {
								?>
								<li><?php esc_html_e('No address found', 'koala-multiple-customer-addresses'); ?></li>
								<?php
							}
							?>
						</ul>
					</tbody>
				</div>
				<?php
			}
			?>
			<?php
		}
	} //class
	new Koala_WSMA_User_Order();
}
