<?php

defined('ABSPATH') || exit;


/**
 * Function for `woocommerce_get_item_data` filter-hook.
 * 
 * @param array $item_data Cart item data. Empty by default.
 * @param array $cart_item Cart item array.
 *
 * @return array
 */

class Koala_WMSA_Front {
	public function __construct() {
		add_action('woocommerce_after_edit_account_address_form', array( $this, 'Koala_multi_address_user_side_shipping_billing' ));
		add_action('wp_enqueue_scripts', array( $this, 'my_user_side_load_scripts' ));
		add_action('woocommerce_before_checkout_billing_form', array( $this, 'cart_page_drop_down_billing' ));
		add_action('woocommerce_review_order_after_payment', array( $this, 'test_cart_model' ));
		add_action('woocommerce_before_checkout_shipping_form', array( $this, 'cart_page_drop_down_shipping' ));
		add_filter('woocommerce_checkout_fields', array( $this, 'wmsa_shipping_custom_fields' ));
		add_action('wp_head', array( $this, 'wmsa_cutom_css' ));
		add_filter('woocommerce_billing_fields', array( $this, 'wmsa_company_fields_billing' ));
		add_filter('woocommerce_shipping_fields', array( $this, 'wmsa_company_fields_shipping' ));
		add_action( 'woocommerce_before_checkout_shipping_form', array( $this, 'action_woocommerce_checkout_billing' )); 
		add_filter( 'woocommerce_get_item_data', array( $this, 'wp_kama_woocommerce_get_item_data_filter' ), 10, 2 );
		add_action('woocommerce_checkout_create_order_line_item', array( $this, 'save_as_custom_order_item_meta_data' ), 10, 4 );
	}
	public function save_as_custom_order_item_meta_data( $item, $cart_item_key, $values, $order ) {
		$user_id = get_current_user_id();

		$all_shipping = get_user_meta($user_id, 'all_shipping_address', true);

		// Check if we have valid shipping address data
		if ( isset($values['address_id_shipping']) && !empty($all_shipping) ) {
			$address_id = sanitize_text_field($values['address_id_shipping']);

			if (isset($all_shipping[ $address_id ])) {
				$shipping_data = $all_shipping[ $address_id ];
		  
				$street_shipping  = $shipping_data['street_address_shipping'];
				$street2_shipping = $shipping_data['street_address_shipping2'];
				$item->update_meta_data('Address 1', $street_shipping);
				$item->update_meta_data('Address 2', $street2_shipping);
			}

			if ( isset($values['shipping_address']) ) {
				$item->update_meta_data('Address', $values['shipping_address']);
			}
		}
	}

	public function wp_kama_woocommerce_get_item_data_filter( $item_data, $cart_item ) {

		if ( isset( $cart_item['address'] ) ) {
			$item_data[] = array(
				'key' => 'Address',
				'value' => $cart_item['address'],
			);
		}



		return $item_data;
	}
	public function wmsa_company_fields_billing( $fields ) {
		$select_user_from_switch = get_option('wmsa_user_role');
		$user_id                 = get_current_user_id();
		if (isset($user_id) && 0 !== $user_id) {
			$role = current(wp_get_current_user()->roles);

			if (( is_array($select_user_from_switch) && in_array($role, (array) $select_user_from_switch) ) || ( empty($select_user_from_switch) )) {
				$require_company_billing = get_option('require_company_field_billing');
				if ('1' !== $require_company_billing) {
					$fields['billing_company']['required'] = false;
				} else {
					$fields['billing_company']['required'] = true;
				}
			}
		}
		return $fields;
	}
	public function wmsa_company_fields_shipping( $fields ) {
		$select_user_from_switch = get_option('wmsa_user_role');
		$user_id                 = get_current_user_id();
		if (isset($user_id) && 0 !== $user_id) {
			$role = current(wp_get_current_user()->roles);

			if (( is_array($select_user_from_switch) && in_array($role, (array) $select_user_from_switch) ) || ( empty($select_user_from_switch) )) {
				$require_company_shipping = get_option('require_company_field_shipping');
				if ('1' !== $require_company_shipping) {
					$fields['shipping_company']['required'] = false;
				} else {
					$fields['shipping_company']['required'] = true;
				}
			}
		}
		return $fields;
	}
	public function wmsa_cutom_css() {
		$select_user_from_switch = get_option('wmsa_user_role');
		$user_id                 = get_current_user_id();
		if (isset($user_id) && 0 !== $user_id) {
			$role = current(wp_get_current_user()->roles);
			if (( is_array($select_user_from_switch) && in_array($role, (array) $select_user_from_switch) ) || ( empty($select_user_from_switch) )) {
				if (is_account_page()) {
					$custom_css_myaccount = get_option('custom_css_account_key_field');
					?>
					<style>
						<?php
						echo esc_attr($custom_css_myaccount);
						?>
					</style>
					<?php
				}
				if (is_checkout()) {
					$custom_css_checkout = get_option('custom_css_checkout_key_field');
					?>
					<style>
						<?php
						echo esc_attr($custom_css_checkout);
						?>
					</style>

					<?php
				}

				?>

				<style>
					.load_more_styling {
						background-color: <?php echo esc_attr(get_option('load_more_background_color_setting')); ?> !important;
						color: <?php echo esc_attr(get_option('load_more_text_color_setting')); ?> !important;
						border-color: <?php echo esc_attr(get_option('load_more_background_color_setting')); ?> !important;
					}

					.load_more_styling:hover {
						background-color: white !important;
						color: <?php echo esc_attr(get_option('load_more_background_color_setting')); ?> !important;
						border: 2px solid !important;
						border-color: <?php echo esc_attr(get_option('load_more_background_color_setting')); ?> !important;
					}

					.chk_a_style {
						color: <?php echo esc_attr(get_option('text_color_add_address_checkout')); ?> !important;
					}

					.chk_a_style:hover {
						cursor: pointer !important;
					}
				</style>
				<?php

			}
		}
	}
	public function wmsa_shipping_custom_fields( $fields ) {
		$select_user_from_switch = get_option('wmsa_user_role');
		$user_id                 = get_current_user_id();
		if (isset($user_id) && 0 !== $user_id) {
			$role = current(wp_get_current_user()->roles);
			if (( is_array($select_user_from_switch) && in_array($role, (array) $select_user_from_switch) ) || ( empty($select_user_from_switch) )) {
				$add_shipping_phone = get_option('add_shipping_phone_option');
				if ('1' === $add_shipping_phone) {
					$require_phone = get_option('require_shipping_phone');
					if ('1' === $require_phone) {
						$fields['shipping']['shipping_phone'] = array(
							'label'    => 'Phone',
							'required' => true,
							'class'    => array( 'form-row-wide' ),
							'priority' => 100,
						);
					} else {
						$fields['shipping']['shipping_phone'] = array(
							'label'    => 'Phone',
							'required' => false,
							'class'    => array( 'form-row-wide' ),
							'priority' => 100,
						);
					}
				}
				$add_shipping_email = get_option('add_shipping_email_option');
				if ('1' === $add_shipping_email) {
					$require_email = get_option('require_shipping_email');
					if ('1' === $require_email) {
						$fields['shipping']['shipping_email'] = array(
							'label'    => 'Email address',
							'required' => true,
							'class'    => array( 'form-row-wide' ),
							'priority' => 100,
						);
					} else {
						$fields['shipping']['shipping_email'] = array(
							'label'    => 'Email address',
							'required' => false,
							'class'    => array( 'form-row-wide' ),
							'priority' => 100,
						);
					}
				}
			}
		}

		return $fields;
	}
	public function action_woocommerce_checkout_billing() {
		if ( is_user_logged_in() ) {
			global $post;

			$product_id = array();
			$cs_meta_val = get_post_meta($post->ID);
			$shipdiffad = get_option('Shipping_address');
			$user_id = get_current_user_id();
			$select_user_from_switch = get_option('wmsa_user_role');
			$selected_data = (int) get_user_meta($user_id, 'default_billing_meta', true);
			$Design_layout = get_option('Design_layout');
			$select_label = get_option('default_select_key_field');

			// Get an instance of the WC_Customer Object from the user ID
			$customer = new WC_Customer($user_id);

			if ('1' == $shipdiffad) {
				?>
				<input type="checkbox" name="differentaddress" class="mca_checkdo">
				<label class="mca_doyo"><?php echo esc_html__('Do you want to ship to multiple addresses?', 'koala-multiple-customer-addresses'); ?></label>
				<?php
			}
			?>
			<div id="mca_layout_container">
				<?php
				$layout_id = 'popup' === $Design_layout ? 'popup_layout' : 'normal_layout';
				$layout_class = 'popup' === $Design_layout ? 'popup_content' : 'checkout_form';

				?>
			 <div id="<?php echo $layout_id; ?>" class="mca_layout <?php echo 'popup' === $Design_layout ? 'popup' : ''; ?>">
					<?php
					if ('popup'=== $Design_layout) {
						?>
						<span id="close-popup" class="close-btn">&times;</span>
						<?php
					}
					?>
					<form action="" id="checkout_form" class="<?php echo esc_attr($layout_class); ?>" method="post">
						<div class="kamca_info">
							<div class="mca_header">
								<div class="mca_pro"><b><?php esc_html_e('Product', 'koala-multiple-customer-addresses'); ?></b></div>
								<div class="mca_qua"><b><?php esc_html_e('Quantity', 'koala-multiple-customer-addresses'); ?></b></div>
								<div class="mca_ad"><b><?php esc_html_e('Sent To', 'koala-multiple-customer-addresses'); ?></b></div>
							</div>

							<?php
							foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
								$product = $cart_item['data'];
								$quantity = $cart_item['quantity'];
								$product_id = $cart_item['product_id'];
								$product = wc_get_product($product_id);
								$name = $product->get_title();
								$image = $product->get_image();

								$args = array(
									'post_type' => 'ka_content_rule',
									'post_status' => 'publish',
									'numberposts' => -1,
									'orderby' => 'menu_order',
									'order' => 'ASC',
									'fields' => 'ids',
								);
								$get_post_data = get_posts($args);

								$flag_mca = false;
								foreach ($get_post_data as $rules) {
									$pro = get_post_meta($rules, 'kanyp_product_rules', true);
									$cat = get_post_meta($rules, 'kanyp_category_rules', true);

									if (in_array($product_id, $pro) || array_intersect($cat, $product->get_category_ids())) {
										$flag_mca = true;
										break;
									}
								}
								?>
								<div class="mca_items mca_items<?php echo esc_attr($cart_item_key); ?>">
									<div class="mca_img"><?php echo wp_kses_post($image); ?></div>
									<div class="mca_name"><?php echo esc_html($name); ?></div>
									<div class="mca_quan" id="mca_quan_<?php echo esc_attr($product_id); ?>">
										<input type="number" name="item_multi_address[<?php echo esc_attr($cart_item_key); ?>][1][qty]" class="qty" min="0" value="<?php echo esc_attr($quantity); ?>">
									</div>
									<div class="mca_add" id="mca_add_<?php echo intval($product_id); ?>">
										<select class="extra_select" name="item_multi_address[<?php echo esc_attr($cart_item_key); ?>][1][address]">
										<?php 
										$select_label = get_option('default_select_key_field', esc_html__('Select an address', 'koala-multiple-customer-addresses'));
										$selected = $user_selected_address == $select_label ? 'selected' : '';
										?>
										<option value="<?php echo esc_attr($select_label); ?>" <?php echo esc_attr($selected); ?>><?php echo esc_html($select_label); ?></option>
										<?php
										foreach ($all_shipping as $key => $value) : 
											$address_identifier_shipping = isset($value['address_identifier_shipping']) ? esc_attr($value['address_identifier_shipping']) : 'Unknown';
											$selected = $user_selected_address == $address_identifier_shipping ? 'selected' : '';
											?>
											<option value="<?php echo esc_attr($address_identifier_shipping); ?>" <?php echo esc_attr($selected); ?>><?php echo esc_html($address_identifier_shipping); ?></option>

										<?php endforeach; ?>
									</select><br>
								</div>

								</div>
								<?php if ($flag_mca) : ?>
									<div class="mca_link">
										<p>This item can be shipped to the default address only</p>
									</div>
								<?php else : ?>
									<div class="mca_link" data-pro_id="<?php echo esc_attr($product_id); ?>">
										<input type="hidden" name="pro_id[<?php echo esc_attr($cart_item_key); ?>][]" value="<?php echo esc_attr($product_id); ?>">
										<a href="#" data-cart_item_key="<?php echo esc_attr($cart_item_key); ?>" class="mca_chnage_text" data-product_id="<?php echo esc_attr($product_id); ?>">
											Ship this item to another address
										</a>
									</div>
								<?php endif; ?>
							<?php } ?>
						<input type="submit" name="update" class="update_btn kaama-update_btn">
						</div>
					</form>
				</div>
			</div>
			<?php
		}
	}


	public function my_user_side_load_scripts() {
		wp_enqueue_script('ka-front-js', WMSA_URL . 'assets/js/front.js', '1.0.0', array( 'jquery' ), true);
		if (is_wc_endpoint_url('edit-address')) {
			wp_enqueue_script('Custom_Script_billing', WMSA_URL . 'assets/js/koala_multiple_addresses_front_billingform.js', '1.0.0', array( 'jquery' ), true);
			wp_enqueue_script('Custom_Script_shipping', WMSA_URL . 'assets/js/koala_multiple_addresses_front_shippingform.js', '1.0.0', array( 'jquery' ), true);
		}
		if (is_checkout() || is_account_page()) {
			wp_enqueue_script('Custom_Script_billing_cart', WMSA_URL . 'assets/js/koala_multiple_addresses_cart.js', '1.0.0', array( 'jquery' ), true);
			wp_register_style('my_css_front_side', WMSA_URL . 'assets/css/koala_multiple_addresses_fR0nt_side.css', false, '1.0.0');
			wp_enqueue_style('my_css_front_side');
			wp_register_style('my_css_front_side_model', WMSA_URL . 'assets/css/koala_multiple_addresses_front_side_billing.css', false, '1.0.0');
			wp_enqueue_style('my_css_front_side_model');
		}
		$koala_multi_address_ajax_front_data = array(
			'admin_url' => admin_url('admin-ajax.php'),
			'nonce'     => wp_create_nonce('multi_address_nonce_admin'),
		);
		wp_localize_script('Custom_Script_billing', 'koala_multi_country_front', $koala_multi_address_ajax_front_data);
		wp_enqueue_script('jquery');
		$user_id     = get_current_user_id();
		$radio_state = get_user_meta($user_id, 'default_billing_meta', true);
		if ('a' !== $radio_state) {
			$all_shipping = get_user_meta($user_id, 'all_billing_address', true);
			if (!empty($all_shipping)) {
				foreach ($all_shipping as $key => $value) {
					if ($key == $radio_state) {
						$fname   = $all_shipping[ $key ]['first_name_billing'];
						$lname   = $all_shipping[ $key ]['last_name_billing'];
						$cname   = $all_shipping[ $key ]['copmany_name_billing'];
						$country = $all_shipping[ $key ]['country_billing'];
						$state   = $all_shipping[ $key ]['country_state'];
						$street  = $all_shipping[ $key ]['street_address_billing'];
						$street2 = $all_shipping[ $key ]['street_address_billing2'];
						$town    = $all_shipping[ $key ]['town_address_billing'];
						$postal  = $all_shipping[ $key ]['postal_code_billing'];
						$phone   = $all_shipping[ $key ]['phone_billing'];
						$email   = $all_shipping[ $key ]['email_billing'];
						$default = "<?php esc_html_e('wmsadefaultbill') ?>";
					}
				}
			}
		} else {
			$default = "<?php esc_html_e('woodefaultbill') ?>";
		}
		$countr_obj = new WC_Countries();
		$state_code = 'abc';
		if (isset($country)) {
			$a = $countr_obj->get_states($country);
		}
		if (!empty($a)) {

			foreach ($a as $key => $value) {
				if (isset($state)) {

					if ($value == $state) {

						$state_code = $key;
					}
				}
			}
			$state = $state_code;
		}

		$radio_state_shipping = get_user_meta($user_id, 'default_shipping_meta', true);
		if ('b' !== $radio_state_shipping) {
			$all_shipping = get_user_meta($user_id, 'all_shipping_address', true);
			if (!empty($all_shipping)) {
				foreach ($all_shipping as $key => $value) {
					if ($key == $radio_state_shipping) {
						$idname_shipping  = $all_shipping[ $key ]['address_identifier_shipping'];
						$fname_shipping   = $all_shipping[ $key ]['first_name_shipping'];
						$lname_shipping   = $all_shipping[ $key ]['last_name_shipping'];
						$cname_shipping   = $all_shipping[ $key ]['copmany_name_shipping'];
						$country_shipping = $all_shipping[ $key ]['country_name_shipping'];
						$state_shipping   = $all_shipping[ $key ]['country_state_shipping'];
						$street_shipping  = $all_shipping[ $key ]['street_address_shipping'];
						$street2_shipping = $all_shipping[ $key ]['street_address_shipping2'];
						$town_shipping    = $all_shipping[ $key ]['town_address_shipping'];
						$pin_shipping     = $all_shipping[ $key ]['pin_code_shipping'];
						$phone_shipping   = $all_shipping[ $key ]['phone_shipping'];
						$email_shipping   = $all_shipping[ $key ]['email_shipping'];
						$default_shipping = "<?php esc_html_e('wmsadefaultship') ?>";
					}
				}
			}
		} else {
			$default_shipping = "<?php esc_html_e('woodefaultship') ?>";
		}
		$countr_obj = new WC_Countries();
		$state_code = 'abc';
		if (isset($country_shipping)) {
			$a = $countr_obj->get_states($country_shipping);
		}
		if (!empty($a)) {

			foreach ($a as $key => $value) {
				if (isset($state_shipping)) {

					if ($value == $state_shipping) {

						$state_code = $key;
					}
				}
			}
			$state_shipping = $state_code;
		}


		$koala_multi_address_cart = array(
			'admin_url' => admin_url('admin-ajax.php'),
			'nonce'     => wp_create_nonce('multi_address_nonce_admin'),
			'fname'     => isset($fname) ? sanitize_text_field($fname) : '',
			'lname'     => isset($lname) ? sanitize_text_field($lname) : '',
			'cname'     => isset($cname) ? sanitize_text_field($cname) : '',
			'country'   => isset($country) ? sanitize_text_field($country) : '',
			'state'     => isset($state) ? sanitize_text_field($state) : '',
			'street'    => isset($street) ? sanitize_text_field($street) : '',
			'street2'   => isset($street2) ? sanitize_text_field($street2) : '',
			'town'      => isset($town) ? sanitize_text_field($town) : '',
			'postal'    => isset($postal) ? sanitize_text_field($postal) : '',
			'phone'     => isset($phone) ? sanitize_text_field($phone) : '',
			'email'     => isset($email) ? sanitize_text_field($email) : '',
			'default'   => isset($default) ? sanitize_text_field($default) : '',
			'default_shipping'   => isset($default_shipping) ? sanitize_text_field($default_shipping) : '',
			'fname_shipping'     => isset($fname_shipping) ? sanitize_text_field($fname_shipping) : '',
			'lname_shipping'     => isset($lname_shipping) ? sanitize_text_field($lname_shipping) : '',
			'cname_shipping'     => isset($cname_shipping) ? sanitize_text_field($cname_shipping) : '',
			'country_shipping'   => isset($country_shipping) ? sanitize_text_field($country_shipping) : '',
			'state_shipping'     => isset($state_shipping) ? sanitize_text_field($state_shipping) : '',
			'street_shipping'    => isset($street_shipping) ? sanitize_text_field($street_shipping) : '',
			'street2_shipping'   => isset($street2_shipping) ? sanitize_text_field($street2_shipping) : '',
			'town_shipping'      => isset($town_shipping) ? sanitize_text_field($town_shipping) : '',
			'pin_shipping'       => isset($pin_shipping) ? sanitize_text_field($pin_shipping) : '',
			'phone_shipping'     => isset($phone_shipping) ? sanitize_text_field($phone_shipping) : '',
			'email_shipping'     => isset($email_shipping) ? sanitize_text_field($email_shipping) : '',
			'admca_multiple_address_shipping' => get_user_meta( $user_id, 'admca_multiple_address_shipping', true ),
		);

		ob_start();
		?>

		 <div class="mca_quan" id="mca_quan_">
			 <input type="number" id="hidden" name="item_multi_address[cart_key][index][qty]" class="qty" min="0" value="">
		 </div>
		 <div class="mca_add" id="mca_add_">

			 <select  class="extra_select" name="item_multi_address[cart_key][index][address]">
			   <?php
				$select_label = get_option('default_select_key_field');
				$selected_data =  get_user_meta($user_id, 'default_shipping_meta', true);

				$all_shipping = get_user_meta($user_id, 'all_shipping_address', true);
				if (!empty($select_label)) {
					?>
					 <option value="<?php echo esc_attr($select_label); ?>" ><?php echo esc_attr($select_label); ?></option>
					<?php
				} else {
					?>
					 <option><?php esc_html_e('Select an address', 'koala-multiple-customer-addresses'); ?></option>
					<?php
				}
				?>
				<?php
				foreach ($all_shipping as $key => $value) {
					?>
					 <option name="get_key" class="get_address_key" value="<?php echo esc_attr($all_shipping[ $key ]['address_identifier_shipping']); ?>" <?php echo selected($key, $selected_data); ?>>
						<?php
						echo esc_attr($all_shipping[ $key ]['address_identifier_shipping']);
						?>
					 </option>
					<?php
				}
				?>
			 </select>
		 </div>
		<?php

		$multiple_address_select_tag = ob_get_clean();

		$koala_multi_address_cart['multiple_address_select_tag'] = $multiple_address_select_tag;

		wp_localize_script('Custom_Script_billing_cart', 'koala_multi_country_cart', $koala_multi_address_cart);
		wp_localize_script('ka-front-js', 'koala_multi_country_cart', $koala_multi_address_cart);

		wp_enqueue_script('jquery');
	}
	public function Koala_multi_address_user_side_shipping_billing() {
		global $wp_query;
		$check_form_load = '';
		foreach ($wp_query as $key => $value) {
			if ('query_vars' == $key) {
				$check_form_load = $value['edit-address'];
			}
		}
		$user_id = get_current_user_id();
		if ('' != $check_form_load) {
			return false;
		} else {
			?>
			 <form method="post">
				 <div id="my_billing_Modal" class="billing_modal">
					 <div class="modal_content_billing">
						 <span class="billing_model_close">&times;</span><br>
						 <div class="message_billing_myaccount"></div>
						<?php
						$getidentifier = get_option('disable_identifier_name');
						if ('1' !== $getidentifier) {
							?>
							 <div class="wms-row">
								 <div class="wms-col-12">
									 <label class="mylabel"><?php esc_html_e('Identifier / Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									 <input placeholder="<?php esc_html_e('Example:Office address', 'oala-multiple-customer-addresses'); ?>" class="inputsize" type="text" name="identifier_name_billing">
								 </div>
							 </div>
							<?php
						}
						?>
						 <div class="wms-row">
							 <div class="wms-col-6">
								 <label class="mylabel"><?php esc_html_e('First Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								 <input class="name_size" type="text" name="first_name_billing">
							 </div>
							 <div class="wms-col-6">
								 <label class="mylabel"><?php esc_html_e('Last Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								 <input class="name_size" type="text" name="last_name_billing">
							 </div>
						 </div>

						<?php
						$require_company_billing = get_option('require_company_field_billing');
						if ('1' === $require_company_billing) {
							?>
							 <div class="wms-row">
								 <div class="wms-col-12">
									 <label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									 <input class="inputsize" type="text" name="copmany_name_billing_required">
								 </div>
							 </div>
							<?php
						} else {
							?>
							 <div class="wms-row">
								 <div class="wms-col-12">
									 <label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?></label>
									 <input class="inputsize" type="text" name="copmany_name_billing">
								 </div>
							 </div>
							<?php
						}
						?>
						 <div class="wms-row">
							 <div class="wms-col-6">
								 <label class="mylabel"><?php esc_html_e('Choose Country', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								 <select name="country_name_billing" id="cor_countries_billing_front">

									<?php
									$countr_obj = new WC_Countries();
									$countries  = $countr_obj->__get('countries');
									foreach ($countries as $key => $country) {
										?>
										 <option value="<?php echo esc_html($key); ?>">
											<?php echo esc_html__($country, 'koala-multiple-customer-addresses'); ?>
										 </option>
										<?php
									}
									?>
								 </select>
							 </div>
							 <div class="wms-col-6">
								 <div class="state_val_add_billing_front">
								 </div>
							 </div>
						 </div>
						 <div class="wms-row">
							 <div class="wms-col-12">
								 <label class="mylabel"><?php esc_html_e('Street Address', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								 <input placeholder="<?php esc_html_e('House number and street number', 'koala-multiple-customer-addresses'); ?>" class="inputsize" type="text" name="st_address_billing">
							 </div>
						 </div>
						 <div class="wms-row">
							 <div class="wms-col-12">
								 <input class="inputsize" placeholder="<?php esc_html_e('Apartment, suite, unit, etc.(optional)', 'koala-multiple-customer-addresses'); ?>" type="text" name="st_address_billing2">
								 <input type="hidden" name="user_id" value="<?php echo esc_attr($user_id); ?>">
							 </div>
						 </div>
						 <div class="wms-row">
							 <div class="wms-col-6">
								 <label class="mylabel"><?php esc_html_e('Town/City', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								 <input class="inputsize" type="text" name="town_address_billing" placeholder="">
							 </div>
							 <div class="wms-col-6">
								 <label class="mylabel"><?php esc_html_e('Postal code', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								 <input class="inputsize" type="text" name="postal_code_billing" placeholder="">
							 </div>
						 </div>
						 <div class="wms-row">

							 <div class="wms-col-6">
								 <label class="mylabel"><?php esc_html_e('Phone', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								 <input class="inputsize" type="number" name="phone_billing" placeholder="">
							 </div>
							 <div class="wms-col-6">
								 <label class="mylabel"><?php esc_html_e('Email Address', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								 <input class="inputsize" type="Email" name="email_billing" placeholder="">
							 </div>
						 </div>
						 <div class="wms-row">
							 <div class="wms-col-12">
								 <div class="save_button"><input type="button" class="buttonstyle billing_form_submit_front" name="billing_form_submit_front" value="Save"></div>
							 </div>
						 </div>
					 </div>
				 </div>
			 </form>
			 <form method="post">
				 <div id="my_billing_model_edit" class="billing_model_edit">
					 <div class="billing_modal_edit_content">
						 <span class="billing_edit_close">&times;</span>
						 <div class="message_b_edit"></div>
						<?php
						$getidentifier = get_option('disable_identifier_name');
						if ('1' !== $getidentifier) {
							?>

							 <div class="wms-row">
								 <div class="wms-col-12">
									 <label class="mylabel"><?php esc_html_e('Identifier / Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									 <input type="hidden" placeholder="<?php esc_html_e('Example:Office address,Mary Jones,MJ 2145', 'koala-multiple-customer-addresses'); ?>" name="edit_id_billing" id="billing_edit_id">
									 <input class="inputsize" type="text" id="identifier_name_billing_edit" name="identifier_name_billing_edit">
								 </div>
							 </div>

						<?php } else { ?>

							 <div class="wms-row">
								 <div class="wms-col-12">
									 <input type="hidden" name="edit_id_billing" id="billing_edit_id">
									 <input class="inputsize" type="hidden" id="identifier_name_billing_edit" name="identifier_name_billing_model_edit_hidden">
								 </div>
							 </div>

						<?php } ?>

						 <div class="wms-row">
							 <div class="wms-col-6">
								 <label class="mylabel"><?php esc_html_e('First Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								 <input type="text" name="first_name_billing_edit" id="first_name_billing_edit">
							 </div>
							 <div class="wms-col-6">
								 <label class="mylabel"><?php esc_html_e('Last Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								 <input type="text" id="last_name_billing_edit" name="last_name_billing_edit">
							 </div>
						 </div>
						 <input type="hidden" name="user_id" value="<?php echo esc_attr($user_id); ?>">

						<?php
						$require_company_billing = get_option('require_company_field_billing');
						if ('1' === $require_company_billing) {
							?>
							 <div class="wms-row">
								 <div class="wms-col-12">
									 <label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									 <input class="inputsize" type="text" id="copmany_name_billing_edit_required" name="copmany_name_billing_edit_required">
								 </div>
							 </div>

						<?php } else { ?>

							 <div class="wms-row">
								 <div class="wms-col-12">
									 <label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?></label>
									 <input class="inputsize" type="text" id="copmany_name_billing_edit" name="copmany_name_billing_edit">
								 </div>
							 </div>
						<?php } ?>
						 <div class="wms-row">
							 <div class="wms-col-6">
								 <label class="mylabel"><?php esc_html_e('Choose Country', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								 <input type="hidden" name="billing_country1" id="billing_shipping111">
								 <select name="country_name_billing_edit" id="country_name_billing_edit" class="country_name_billing_edit">
									<?php
									$countr_obj = new WC_Countries();
									$countries  = $countr_obj->__get('countries');
									foreach ($countries as $key => $country) {
										?>
										 <option value="<?php echo esc_html($key); ?>">
											<?php echo esc_html__($country, 'koala-multiple-customer-addresses'); ?>
										 </option>
										<?php
									}
									?>
								 </select>
								 <input type="hidden" name="edit_id" id="shipping_edit_id">
							 </div>
							 <div class="wms-col-6">
								 <div id="state_val_edit_billing"></div>
							 </div>
						 </div>

						 <div class="wms-row">
							 <div class="wms-col-12">
								 <label class="mylabel"><?php esc_html_e('Street Address', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								 <input placeholder="<?php esc_html_e('House number and street number', 'koala-multiple-customer-addresses'); ?>" class="inputsize" type="text" id="st_address_billing_edit" name="st_address_billing_edit">
								 <input placeholder="<?php esc_html_e('Apartment, suite, unit, etc.(optional)'); ?>" class="inputsize" type="text" id="st_address_billing_edit2" name="st_address_billing_edit2">
							 </div>
						 </div>

						 <div class="wms-row">
							 <div class="wms-col-6">
								 <label class="mylabel"><?php esc_html_e('Town/City', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								 <input class="inputsize" type="text" id="town_address_billing_edit" name="town_address_billing_edit" placeholder="">
							 </div>
							 <div class="wms-col-6">
								 <label class="mylabel"><?php esc_html_e('Postal code', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								 <input class="inputsize" type="text" id="postal_code_billing_edit" name="postal_code_billing_edit" placeholder="">
							 </div>
						 </div>

						 <div class="wms-row">
							 <div class="wms-col-6">
								 <label class="mylabel"><?php esc_html_e('Phone', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								 <input class="inputsize" type="number" id="phone_billing_edit" name="phone_billing_edit" placeholder="">
							 </div>
							 <div class="wms-col-6">
								 <label class="mylabel"><?php esc_html_e('Email Address', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
								 <input class="inputsize" type="Email" id="email_billing_edit" name="email_billing_edit" placeholder="">
							 </div>
						 </div>

						 <div class="wms-row">
							 <div class="wms-col-12">
								 <input type="button" class="billing_form_edit_front" name="billing_form_edit_front" value="Save">
							 </div>
						 </div>
					 </div>
				 </div>
			 </form>
			 <form method="post" name="post">
				 <div id="add_button_ref">
					 <div class="left">
						<?php
						$select_user_from_switch = get_option('wmsa_user_role');
						$user_id                 = get_current_user_id();
						if (isset($user_id) && 0 !== $user_id) {
							$role = current(wp_get_current_user()->roles);
							if (( is_array($select_user_from_switch) && in_array($role, (array) $select_user_from_switch) ) || ( empty($select_user_from_switch) )) {

								$get_val = get_option('enable_disable_billing');
								if ('1' !== $get_val) {
									$diable_cap = get_option('disable_user_add_del_billing');
									if ('1' !== $diable_cap) {

										$max_addresses = get_option('max_num_billing');
										if (!empty($max_addresses) && 0 !== $max_addresses) {
											$all_shiiping_add = get_user_meta($user_id, 'all_billing_address', true);
											$count            = 0;
											if (!empty($all_shiiping_add)) {
												foreach ($all_shiiping_add as $key_b => $value) {
													++$count;
												}
											}
											if ($count < $max_addresses) {
												$billing_label = get_option('billing_title_key_field');
												if (empty($billing_label)) {
													$billing_title = 'Add New Billing Address';
												} else {
													$billing_title = $billing_label;
												}
												?>
												 <input id="billing_model" class="load_more_styling" type="button" value="<?php echo esc_html__($billing_title, 'koala-multiple-customer-addresses'); ?>">
												<?php
											}
										} else {
											$billing_label = get_option('billing_title_key_field');
											if (empty($billing_label)) {
												$billing_title = 'Add New Billing Address';
											} else {
												$billing_title = $billing_label;
											}
											?>
											 <input id="billing_model" class="load_more_styling" type="button" value="<?php echo esc_html__($billing_title, 'koala-multiple-customer-addresses'); ?>">
											<?php
										}
									}
								}
							}
						}
						?>

					 </div>
					 <div class="right">
						<?php
						$select_user_from_switch = get_option('wmsa_user_role');
						$user_id                 = get_current_user_id();
						if (isset($user_id) && 0 !== $user_id) {
							$role = current(wp_get_current_user()->roles);
							if (( is_array($select_user_from_switch) && in_array($role, (array) $select_user_from_switch) ) || ( empty($select_user_from_switch) )) {

								$disable_shipping = get_option('enable_disable_shipping');
								if ('1' !== $disable_shipping) {
									$diable_cap_shipping = get_option('disable_user_add_del_shipping');
									if ('1' !== $diable_cap_shipping) {
										$max_addresses_shipping = get_option('max_num_shipping');
										if (!empty($max_addresses_shipping) && 0 !== $max_addresses_shipping) {
											$all_shiiping_add = get_user_meta($user_id, 'all_shipping_address', true);
											$count            = 0;
											if (!empty($all_shiiping_add)) {
												foreach ($all_shiiping_add as $key_t => $value) {
													++$count;
												}
											}
											if ($count < $max_addresses_shipping) {
												$shipping_label = get_option('shipping_title_key_field');
												if (empty($shipping_label)) {
													$shipping_title = __('Add New Shipping Address', 'koala-multiple-customer-addresses');
												} else {
													$shipping_title = $shipping_label;
												}
												?>
												 <input id="shipping_model" type="button" class="load_more_styling" value="<?php echo esc_html__($shipping_title, 'koala-multiple-customer-addresses'); ?>">
												<?php
											}
										} else {
											$shipping_label = get_option('shipping_title_key_field');
											if (empty($shipping_label)) {
												$shipping_title = __('Add New Shipping Address', 'koala-multiple-customer-addresses');
											} else {
												$shipping_title = $shipping_label;
											}
											?>
											 <input id="shipping_model" type="button" class="load_more_styling" value="<?php echo esc_html__($shipping_title, 'koala-multiple-customer-addresses'); ?>">
											<?php
										}
									}
								}
							}
						}
						?>
					 </div>
				 </div>
			 </form>
			<?php
			$select_user_from_switch = get_option('wmsa_user_role');
			$user_id                 = get_current_user_id();
			if (isset($user_id) && 0 !== $user_id) {
				$role = current(wp_get_current_user()->roles);
				if (( is_array($select_user_from_switch) && in_array($role, (array) $select_user_from_switch) ) || ( empty($select_user_from_switch) )) {

					$get_val = get_option('enable_disable_billing');
					if ('1' !== $get_val) {
						?>
						 <form method="post">
							 <div class="table_arc" id="table_arc_front" width="100%">
								<?php
								$all_shiiping_add = get_user_meta($user_id, 'all_billing_address', true);
								if (!empty($all_shiiping_add)) {
									?>
									 <h3 class="address_title">
										<?php
										$billing_myaccount = get_option('billing_myaccount_heading');
										if (!empty($billing_myaccount)) {
											echo esc_attr__($billing_myaccount, 'koala-multiple-customer-addresses');
										} else {
											esc_html_e('Billing Addresses', 'koala-multiple-customer-addresses');
										}
										?>
									 </h3>
									 <ul class="billing_edit">
										<?php

										foreach ($all_shiiping_add as $key => $af_role_his) {
											?>


											 <li class="table_back">
												 <h5>
													<?php $radio_state = get_user_meta($user_id, 'default_billing_meta', true); ?>
													 <input type="hidden" name="user_id" value="<?php echo esc_attr($user_id); ?>">
													<?php $address_label = get_option('default_address_key_field'); ?>
													 <input type="radio" class="default_billing_address_front radio_billing_front" name="default_billing_front" value="<?php echo esc_attr($key); ?>" <?php checked($radio_state, $key); ?>>
													<?php
													if (!empty($address_label)) {
														echo esc_attr($address_label);
													} else {
														?>
														<?php esc_html_e('Set Default Address', 'koala-multiple-customer-addresses'); ?>
														<?php
													}
													?>
												 </h5>

												<?php
												$diable_cap = get_option('disable_user_add_del_billing');
												if ('1' !== $diable_cap) {
													$max_addresses = get_option('max_num_billing');
													if (!empty($max_addresses) && 0 !== $max_addresses) {
														$all_shiiping_add = get_user_meta($user_id, 'all_billing_address', true);
														$count            = 0;
														foreach ($all_shiiping_add as $key_b => $value) {
															++$count;
														}
														if ($count < $max_addresses) {
															?>
															 <button type="button" class="action_buttons_style duplicate_billing_front" name="duplicate_billing" value="<?php echo esc_attr($key); ?>"><?php esc_html_e('Duplicate', 'koala-multiple-customer-addresses'); ?></button>
															<?php
														}
													} else {
														?>
														 <button type="button" class="action_buttons_style duplicate_billing_front" name="duplicate_billing" value="<?php echo esc_attr($key); ?>"><?php esc_html_e('Duplicate', 'koala-multiple-customer-addresses'); ?></button>
														<?php
													}
													?>
													 <button type="button" class="billing_edit_front action_buttons_style" id="billing_edit_front" name="edit_billings" value="<?php echo esc_attr($key); ?>">
														<?php esc_html_e('Edit', 'koala-multiple-customer-addresses'); ?></button>
														 <button type="button" class="action_buttons_style delete_address_billing_front" name="delete_address_billing" value="<?php echo esc_attr($key); ?>">
															<?php esc_html_e('Delete', 'koala-multiple-customer-addresses'); ?>
														 </button>
														<?php
												}
												?>
													<?php
													$address_size = get_option('address_title_tag_key_field');
													?>
													 <<?php echo esc_attr($address_size); ?>>
													<?php echo esc_attr($af_role_his['address_identifier_billing']); ?>
													 </<?php echo esc_attr($address_size); ?>>
													 <input type="hidden" name="user_id" value="<?php echo esc_attr($user_id); ?>">
													 <input type="hidden" name="identifier_name_billing_edit_hidden" value=" <?php echo esc_attr($af_role_his['address_identifier_billing']); ?>">
													 <label class="viewlables1"><?php esc_html_e('Name', 'koala-multiple-customer-addresses'); ?></label>
													 <input type="hidden" name="first_name_billing_edit_hidden" value=" <?php echo esc_attr($af_role_his['first_name_billing']); ?>">
													 <input type="hidden" name="last_name_billing_edit_hidden" value=" <?php echo esc_attr($af_role_his['last_name_billing']); ?>">
													<?php echo esc_attr($af_role_his['first_name_billing']); ?>
													<?php echo esc_attr($af_role_his['last_name_billing']); ?>
													 <label class="viewlables1"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?></label>
													 <input type="hidden" name="copmany_name_billing_edit_hidden" value=" <?php echo esc_attr($af_role_his['copmany_name_billing']); ?>">
													<?php echo esc_attr($af_role_his['copmany_name_billing']); ?>
													 <label class="viewlables1"><?php esc_html_e('Country', 'koala-multiple-customer-addresses'); ?></label>
													<?php
													$country_decoded_name = $af_role_his['country_billing'];
													$countr_obj           = new WC_Countries();
													$countries            = $countr_obj->__get('countries');
													?>
													 <input type="hidden" name="get_country_code_billing" value="<?php echo esc_html__($country_decoded_name, 'koala-multiple-customer-addresses'); ?>">
													<?php
													foreach ($countries as $key => $country) {

														if ($key == $country_decoded_name) {
															echo esc_html__($country, 'koala-multiple-customer-addresses');
															?>
															 <input type="hidden" name="country_name_billing_hidden" value="<?php echo esc_html__($country, 'koala-multiple-customer-addresses'); ?>">
															<?php
														}
													}
													$a = $countr_obj->get_states($country_decoded_name);

													if ( !empty( $a ) ) {
														?>
														 <label class="viewlables1"><?php esc_html_e('State', 'koala-multiple-customer-addresses'); ?></label>
														<?php
														echo esc_attr($af_role_his['country_state']);
													} else {
														?>
														 <label class="viewlables1"><?php esc_html_e('County', 'koala-multiple-customer-addresses'); ?></label>
														<?php
														echo esc_attr($af_role_his['country_state']);
													}
													?>
													 <label class="viewlables1"><?php esc_html_e('Street Address', 'koala-multiple-customer-addresses'); ?></label>
													<?php echo esc_attr($af_role_his['street_address_billing']); ?>
													<?php echo esc_attr($af_role_his['street_address_billing2']); ?>
													 <input type="hidden" name="street_address_billing_edit_hidden" value=" <?php echo esc_attr($af_role_his['street_address_billing']); ?>">
													 <input type="hidden" name="street_address_billing_edit_hidden2" value=" <?php echo esc_attr($af_role_his['street_address_billing2']); ?>">
													 <label class="viewlables1"><?php esc_html_e('Town/City', 'koala-multiple-customer-addresses'); ?></label>
													<?php echo esc_attr($af_role_his['town_address_billing']); ?>
													 <input type="hidden" name="town_address_billing_edit_hidden" value=" <?php echo esc_attr($af_role_his['town_address_billing']); ?>">
													 <label class="viewlables1"><?php esc_html_e('Postal Code', 'koala-multiple-customer-addresses'); ?></label>
													<?php echo esc_attr($af_role_his['postal_code_billing']); ?>
													 <input type="hidden" name="postal_code_billing_edit_hidden" value=" <?php echo esc_attr($af_role_his['postal_code_billing']); ?>">
													 <label class="viewlables1"><?php esc_html_e('Phone Number', 'koala-multiple-customer-addresses'); ?></label>
													<?php echo esc_attr($af_role_his['phone_billing']); ?>
													 <input type="hidden" name="phone_name_billing_edit_hidden" value=" <?php echo esc_attr($af_role_his['phone_billing']); ?>">
													 <label class="viewlables1"><?php esc_html_e('Email', 'koala-multiple-customer-addresses'); ?></label>
													<?php echo esc_attr($af_role_his['email_billing']); ?>
													 <input type="hidden" name="email_billing_edit_hidden" value=" <?php echo esc_attr($af_role_his['email_billing']); ?>">
												 </li>

												<?php
										}
								} else {
									?>
								<?php } ?>
									 </ul>
								 </div>
							 </form>
							<?php
					}
				}
			}

			?>
				 <form method="post">
					 <div id="my_shipping_modal_id" class="shipping_modal_view">
						 <div class="shipping_modal_content">
							 <span class="shipping_close">&times;</span>
							 <div class="message_shipping"> </div>
							<?php
							$getidentifier = get_option('disable_identifier_name');
							if ('1' !== $getidentifier) {
								?>
								 <div class="wms-row">
									 <div class="wms-col-12">
										 <label class="mylabel"><?php esc_html_e('Identifier / Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
										 <input placeholder="<?php esc_html_e('Example:Office address,Mary Jones,MJ 2145', 'koala-multiple-customer-addresses'); ?>" class="inputsize" type="text" name="identifier_name_shipping">
									 </div>
								 </div>
								<?php
							}
							?>
							 <div class="wms-row">
								 <div class="wms-col-6">
									 <label class="mylabel"><?php esc_html_e('First Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									 <input type="text" name="first_name_shipping">
								 </div>
								 <div class="wms-col-6">
									 <label class="mylabel"><?php esc_html_e('Last Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									 <input type="text" name="last_name_shipping">
								 </div>
							 </div>

							<?php
							$require_company_shipping = get_option('require_company_field_shipping');
							if ('1' === $require_company_shipping) {
								?>
								 <div class="wms-row">
									 <div class="wms-col-12">
										 <label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
										 <input class="inputsize" type="text" name="copmany_name_shipping_required">
									 </div>
								 </div>
								<?php
							} else {
								?>
								 <div class="wms-row">
									 <div class="wms-col-12">
										 <label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?></label>
										 <input class="inputsize" type="text" name="copmany_name_shipping">
									 </div>
								 </div>
								<?php
							}
							?>
							 <div class="wms-row">
								 <div class="wms-col-6">
									 <label class="mylabel"><?php esc_html_e('Choose Country', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									 <select name="country_name_shipping" id="cor_countries_shipping_front">
										<?php
										$countr_obj = new WC_Countries();
										$countries  = $countr_obj->__get('countries');
										foreach ($countries as $key => $country) {
											?>
											 <option value="<?php echo esc_html($key); ?>">
												<?php echo esc_html__($country, 'koala-multiple-customer-addresses'); ?>

											 </option>
											<?php
										}
										?>
									 </select>
								 </div>

								 <div class="wms-col-6">
									 <div class="state_val_add_shipping_front">
									 </div>
								 </div>
							 </div>
							 <div class="wms-row">
								 <div class="wms-col-12">
									 <label class="mylabel"><?php esc_html_e('Street Address', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									 <input class="inputsize" placeholder="<?php esc_html_e('House number and street number', 'koala-multiple-customer-addresses'); ?>" type="text" name="st_address_shipping">
								 </div>
							 </div>
							 <div class="wms-row">
								 <div class="wms-col-12">
									 <input type="hidden" name="user_id" value="<?php echo esc_attr($user_id); ?>">
									 <input class="inputsize" placeholder="<?php esc_html_e('Apartment, suite, unit, etc.(optional)', 'koala-multiple-customer-addresses'); ?>" type="text" name="st_address_shipping2">
								 </div>
							 </div>
							 <div class="wms-row">
								 <div class="wms-col-6">
									 <label class="mylabel"><?php esc_html_e('Town/City', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									 <input class="inputsize" type="text" name="town_address_shipping" placeholder="">
								 </div>
								 <div class="wms-col-6">
									 <label class="mylabel"><?php esc_html_e('Postal code', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									 <input class="inputsize" type="text" name="pin_code_shipping" 	holder="">
								 </div>
							 </div>
							<?php
							$add_shipping_phone = get_option('add_shipping_phone_option');
							?>
							 <div class="wms-row">
								<?php
								if ('1' === $add_shipping_phone) {
									$require_phone = get_option('require_shipping_phone');
									if ('1' === $require_phone) {
										?>
										 <div class="wms-col-6">
											 <label class="mylabel"><?php esc_html_e('Phone', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
											 <input class="inputsize" type="number" name="phone_shipping_required" placeholder="">
										 </div>

										<?php
									} else {
										?>
										 <div class="wms-col-6">
											 <label class="mylabel"><?php esc_html_e('Phone', 'koala-multiple-customer-addresses'); ?></label>

											 <input class="inputsize" type="number" name="phone_shipping" placeholder="">
										 </div>
										<?php
									}
								}
								?>
								<?php
								$add_shipping_email = get_option('add_shipping_email_option');
								if ('1' === $add_shipping_email) {

									$require_email = get_option('require_shipping_email');
									if ('1' === $require_email) {
										?>
										 <div class="wms-col-6">
											 <label class="mylabel"><?php esc_html_e('Email Address', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
											 <input class="inputsize" type="Email" name="email_shipping_required" placeholder="">
										 </div>

										<?php
									} else {
										?>
										 <div class="wms-col-6">
											 <label class="mylabel"><?php esc_html_e('Email Address', 'koala-multiple-customer-addresses'); ?></label>
											 <input class="inputsize" type="Email" name="email_shipping" placeholder="">
										 </div>
										<?php
									}
								}
								?>
							 </div>
							 <div class="wms-row">
								 <div class="wms-col-12">
									 <div align="right"><input type="button" class="buttonstyle shipping_form_submit_front" name="shipping_form_submit_front" value="Save"></div>
								 </div>
							 </div>

						 </div>
					 </div>
				 </form>
				 <form method="post">

					 <div id="my_shipping_model_edit" class="shipping_model_edit">
						 <div class="shipping_modal_edit_content">
							 <span class="shipping_edit_close">&times;</span>
							 <div class="message_shipping_edit"></div>
							<?php
							$getidentifier = get_option('disable_identifier_name');
							if ('1' !== $getidentifier) {
								?>
								 <div class="wms-row">
									 <div class="wms-col-12">
										 <label class="mylabel"><?php esc_html_e('Identifier / Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
										 <input placeholder="<?php esc_html_e('Office address,Mary Jones,MJ 2145', 'koala-multiple-customer-addresses'); ?>" class="inputsize" type="text" id="identifier_name_shipping_edit" name="identifier_name_shipping_edit">
									 </div>
								 </div>
								<?php
							} else {
								?>
								 <input class="inputsize" type="hidden" id="identifier_name_shipping_edit" name="identifier_name_shipping_edit_hidden1">
								<?php
							}
							?>
							 <div class="wms-row">
								 <div class="wms-col-6">
									 <label class="mylabel"><?php esc_html_e('First Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									 <input type="text" name="first_name_shipping_edit" id="first_name_shipping_edit">
								 </div>
								 <div class="wms-col-6">
									 <label class="mylabel"><?php esc_html_e('Last Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									 <input type="text" id="last_name_shipping_edit" name="last_name_shipping_edit">
								 </div>
							 </div>

							<?php
							$require_company_shipping = get_option('require_company_field_shipping');
							if ('1' === $require_company_shipping) {
								?>
								 <div class="wms-row">
									 <div class="wms-col-12">
										 <label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
										 <input class="inputsize" type="text" id="copmany_name_shipping_edit_required" name="copmany_name_shipping_edit_required">
									 </div>
								 </div>
								<?php
							} else {
								?>
								 <div class="wms-row">
									 <div class="wms-col-12">
										 <label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?></label>
										 <input class="inputsize" type="text" id="copmany_name_shipping_edit" name="copmany_name_shipping_edit">
									 </div>
								 </div>
								<?php
							}
							?>
							 <div class="wms-row">
								 <div class="wms-col-6">
									 <label class="mylabel"><?php esc_html_e('Choose Country', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									 <input type="hidden" name="shipping_country1" id="country_shipping111">
									 <select name="country_name_shipping_edit" class="country_name_shipping_edit" id="country_name_shipping_edit">
										<?php
										$countr_obj = new WC_Countries();

										$countries = $countr_obj->__get('countries');
										foreach ($countries as $key => $country) {
											?>
											 <option id=abc value="<?php echo esc_html($key); ?>">
												<?php echo esc_html__($country, 'koala-multiple-customer-addresses'); ?>
											 </option>
											<?php
										}
										?>
									 </select>
								 </div>
								 <div class="wms-col-6">
									 <input type="hidden" name="edit_id_shipping" id="shipping_edit_id_front">
									 <div name="testing_shipping" id="state_val_edit_shipping_front">
									 </div>
								 </div>
							 </div>
							 <div class="wms-row">
								 <div class="wms-col-12">
									 <label class="mylabel"><?php esc_html_e('Street Address', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									 <input class="inputsize" placeholder="<?php esc_html_e('House number and street number', 'koala-multiple-customer-addresses'); ?>" type="text" id="st_address_shipping_edit" name="st_address_shipping_edit">
								 </div>
							 </div>
							 <div class="wms-row">
								 <div class="wms-col-12">
									 <input placeholder="<?php esc_html_e('Office address,Mary Jones,MJ 2145', 'koala-multiple-customer-addresses'); ?>" class="inputsize" type="text" id="st_address_shipping_edit2" name="st_address_shipping_edit2">
								 </div>
							 </div>
							 <div class="wms-row">
								 <div class="wms-col-6">
									 <label class="mylabel"><?php esc_html_e('Town/City', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									 <input class="inputsize" type="text" id="town_address_shipping_edit" name="town_address_shipping_edit" placeholder="">
									 <input type="hidden" name="user_id" value="<?php echo esc_attr($user_id); ?>">
								 </div>
								 <div class="wms-col-6">
									 <label class="mylabel"><?php esc_html_e('Postal code', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									 <input class="inputsize" type="text" id="pin_code_shipping_edit" name="pin_code_shipping_edit" placeholder="">
								 </div>
							 </div>
							<?php
							$add_shipping_phone = get_option('add_shipping_phone_option');
							?>
							 <div class="wms-row">
								<?php
								if ('1' === $add_shipping_phone) {
									$require_phone = get_option('require_shipping_phone');
									if ('1' === $require_phone) {
										?>
										 <div class="wms-col-6">
											 <label class="mylabel"><?php esc_html_e('Phone', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
											 <input class="inputsize" type="number" name="phone_shipping_edit_required" id="phone_shipping_edit_required" placeholder="">
										 </div>
										<?php
									} else {
										?>
										 <div class="wms-col-6">
											 <label class="mylabel"><?php esc_html_e('Phone', 'koala-multiple-customer-addresses'); ?></label>
											 <input class="inputsize" type="number" name="phone_shipping_edit" id="phone_shipping_edit" placeholder="">
										 </div>
										<?php
									}
								}
								?>
								<?php
								$add_shipping_email = get_option('add_shipping_email_option');
								if ('1' === $add_shipping_email) {
									$require_email = get_option('require_shipping_email');
									if ('1' === $require_email) {
										?>
										 <div class="wms-col-6">
											 <label class="mylabel"><?php esc_html_e('Email Address', 'Shipping_addresskoala-multiple-customer-addresses'); ?><span class="required">*</span></label>
											 <input class="inputsize" type="Email" name="email_shipping_edit_required" id="email_shipping_edit_required" placeholder="">
										 </div>
										<?php
									} else {
										?>
										 <div class="wms-col-6">
											 <label class="mylabel"><?php esc_html_e('Email Address', 'koala-multiple-customer-addresses'); ?></label>
											 <input class="inputsize" type="Email" name="email_shipping_edit" id="email_shipping_edit" placeholder="">
										 </div>
										<?php
									}
								}
								?>
							 </div>
							 <div class="wms-row">
								 <div class="wms-col-12">
									 <div align="right"><input type="button" class="shipping_form_edit_fronts" name="shipping_form_edit_front" value="Save"></div>
								 </div>
							 </div>
						 </div>
					 </div>
				 </form>
				<?php
				$select_user_from_switch = get_option('wmsa_user_role');
				$user_id                 = get_current_user_id();
				if (isset($user_id) && 0 !== $user_id) {
					$user_meta  = get_userdata($user_id);
					$user_roles = $user_meta->roles;
					$role;
					foreach ($user_roles as $key => $value) {
						$role = $value;
					}
					if (( is_array($select_user_from_switch) && in_array($role, (array) $select_user_from_switch) ) || ( empty($select_user_from_switch) )) {

						$disable_shipping = get_option('enable_disable_shipping');
						if ('1' !== $disable_shipping) {
							?>
							 <form method="post">
								 <div class="table_arc" id="table_arc_shipping" width="100%">
									 <tbody>
										<?php $all_shiiping_add = get_user_meta($user_id, 'all_shipping_address', true); ?>

										<?php
										if (!empty($all_shiiping_add)) {
											?>
											 <h3 class="address_title">
												<?php
												$shipping_myaccount = get_option('shipping_myaccount_heading');

												if (!empty($shipping_myaccount)) {

													echo esc_attr($shipping_myaccount);
												} else {
													esc_html_e('Shipping Addresses');
												}
												?>
											 </h3>
											 <ul class="delcheck">
												<?php
												foreach ($all_shiiping_add as $key => $af_role_his) {
													?>

													 <li class="table_back">
														<?php
														$address_label = get_option('default_address_key_field');
														?>
														 <h5>
															<?php $radio_state = get_user_meta($user_id, 'default_shipping_meta', true); ?>
															 <input type="hidden" name="user_id" value="<?php echo esc_attr($user_id); ?>">
															 <input type="radio" class="default_shipping_address_front radio_shipping_front" name="default_shipping_front" value="<?php echo esc_attr($key); ?>" <?php checked($radio_state, $key); ?>>
															<?php
															if (!empty($address_label)) {
																echo esc_attr($address_label);
															} else {
																?>
																<?php esc_html_e('Set Default Address', 'koala-multiple-customer-addresses'); ?>
																<?php
															}
															?>

														 </h5>
														<?php
														$diable_cap_shipping = get_option('disable_user_add_del_shipping');
														if ('1' !== $diable_cap_shipping) {
															$max_addresses_shipping = get_option('max_num_shipping');
															if (!empty($max_addresses_shipping) && 0 !== $max_addresses_shipping) {
																$all_shiiping_add = get_user_meta($user_id, 'all_shipping_address', true);
																$count            = 0;
																foreach ($all_shiiping_add as $key_t => $value) {
																	++$count;
																}
																if ($count < $max_addresses_shipping) {
																	?>
																	 <button type="button" class="action_buttons_style duplicate_shipping_front" name="duplicate_shipping" value="<?php echo esc_attr($key); ?>"><?php esc_html_e('Duplicate', 'koala-multiple-customer-addresses'); ?></button>
																	<?php
																}
															} else {
																?>
																 <button type="button" class="action_buttons_style duplicate_shipping_front" name="duplicate_shipping" value="<?php echo esc_attr($key); ?>"><?php esc_html_e('Duplicate', 'koala-multiple-customer-addresses'); ?></button>
																<?php
															}
															?>
															 <button type="button" class="shipping_edit_front action_buttons_style" id="shipping_edit" name="edit_shippings" value="<?php echo esc_attr($key); ?>">
																<?php esc_html_e('Edit', 'koala-multiple-customer-addresses'); ?></button>
																 <button type="button" class="action_buttons_style delete_address_shipping_front" name="delete_address_shipping" value="<?php echo esc_attr($key); ?>">
																	<?php esc_html_e('Delete', 'koala-multiple-customer-addresses'); ?></button>
																	<?php
														}
														?>
																 <input type="hidden" name="user_id" value="<?php echo esc_attr($user_id); ?>">
																<?php
																$address_size = get_option('address_title_tag_key_field');
																?>
																 <<?php echo esc_attr($address_size); ?>>
																<?php echo esc_attr($af_role_his['address_identifier_shipping']); ?>
																 </<?php echo esc_attr($address_size); ?>>
																 <input type="hidden" name="address_id" value=" <?php echo esc_attr($af_role_his['address_identifier_shipping']); ?>">
																 <label class="viewlables1"><?php esc_html_e('Name', 'koala-multiple-customer-addresses'); ?></label>
																 <input type="hidden" name="first_name" value=" <?php echo esc_attr($af_role_his['first_name_shipping']); ?>">
																 <input type="hidden" name="last_name" value=" <?php echo esc_attr($af_role_his['last_name_shipping']); ?>">
																<?php echo esc_attr($af_role_his['first_name_shipping']); ?>
																<?php echo esc_attr($af_role_his['last_name_shipping']); ?>
																 <label class="viewlables1"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?></label>
																<?php echo esc_attr($af_role_his['copmany_name_shipping']); ?>
																 <input type="hidden" name="company_name" value=" <?php echo esc_attr($af_role_his['copmany_name_shipping']); ?>">
																 <label class="viewlables1"><?php esc_html_e('Country', 'koala-multiple-customer-addresses'); ?></label>
																<?php
																$country_decoded_name = $af_role_his['country_name_shipping'];
																?>
																 <input type="hidden" name="country_code_shipping_hidden" value="<?php echo esc_html__($country_decoded_name, 'koala-multiple-customer-addresses'); ?>">
																<?php
																$countr_obj = new WC_Countries();
																$countries  = $countr_obj->__get('countries');
																foreach ($countries as $key => $country) {
																	if ($key == $country_decoded_name) {
																		echo esc_html__($country, 'koala-multiple-customer-addresses');
																		?>
																		 <input type="hidden" name="country_name_shipping_hidden" value="<?php echo esc_html__($country, 'koala-multiple-customer-addresses'); ?>">
																		<?php
																	}
																}

																$a = $countr_obj->get_states($country_decoded_name);

																if ( !empty( $a ) ) {
																	?>
																	 <label class="viewlables1" data-county_or_states="states"><?php esc_html_e('State', 'koala-multiple-customer-addresses'); ?></label>
																	<?php
																	echo esc_attr($af_role_his['country_state_shipping']);
																} else {
																	?>
																	 <label class="viewlables1"><?php esc_html_e('County', 'koala-multiple-customer-addresses'); ?></label>
																	<?php
																	echo esc_attr($af_role_his['country_state_shipping']);
																}
																?>
																 <label class="viewlables1"><?php esc_html_e('Street Address', 'koala-multiple-customer-addresses'); ?></label>
																 <input type="hidden" name="street_name" value=" <?php echo esc_attr($af_role_his['street_address_shipping']); ?>">
																<?php echo esc_attr($af_role_his['street_address_shipping']); ?>
																 <input type="hidden" name="street_name2" value=" <?php echo esc_attr($af_role_his['street_address_shipping2']); ?>">
																<?php echo esc_attr($af_role_his['street_address_shipping2']); ?>
																 <label class="viewlables1"><?php esc_html_e('Town/City', 'koala-multiple-customer-addresses'); ?></label>
																 <input type="hidden" name="town_name" value=" <?php echo esc_attr($af_role_his['town_address_shipping']); ?>">
																<?php echo esc_attr($af_role_his['town_address_shipping']); ?>
																 <label class="viewlables1"><?php esc_html_e('Postal Code', 'koala-multiple-customer-addresses'); ?></label>
																 <input type="hidden" name="pin_name" value=" <?php echo esc_attr($af_role_his['pin_code_shipping']); ?>">
																<?php echo esc_attr($af_role_his['pin_code_shipping']); ?>
																<?php
																$add_shipping_phone = get_option('add_shipping_phone_option');
																if ('1' === $add_shipping_phone) {
																	?>
																	 <label class="viewlables1"><?php esc_html_e('Phone', 'koala-multiple-customer-addresses'); ?></label>
																	 <input type="hidden" name="phone_name_shipping" value=" <?php echo esc_attr($af_role_his['phone_shipping']); ?>">
																	<?php echo esc_attr($af_role_his['phone_shipping']); ?>
																	<?php
																} else {
																	?>
																	 <input type="hidden" name="phone_name_shipping">
																	<?php
																}
																?>
																<?php
																$add_shipping_email = get_option('add_shipping_email_option');
																if ('1' === $add_shipping_email) {
																	?>
																	 <label class="viewlables1"><?php esc_html_e('email', 'koala-multiple-customer-addresses'); ?></label>
																	 <input type="hidden" name="email_name_shipping" value=" <?php echo esc_attr($af_role_his['email_shipping']); ?>">
																	<?php echo esc_attr($af_role_his['email_shipping']); ?><br>
																	<?php
																} else {
																	?>
																	 <input type="hidden" name="email_name_shipping">
																	<?php
																}
																?>
															 </li>

															<?php
												}
										} else {
											?>
										<?php } ?>
												 </ul>
											 </tbody>
										 </div>
									 </form>
									<?php
						}
					}
				}
				?>
						<?php

		}
	}
	public function test_cart_model() {
		?>
					 <form method="post">
						 <div id="cart_modal_id" class="cart_model_class">
							 <div class="cart_model_content">
								 <span class="cart_m_exit">&times;</span>
								 <div class="message_billing"></div>
					<?php
					$getidentifier = get_option('disable_identifier_name');
					if ('1' !== $getidentifier) {
						?>
									 <div class="wms-row">
										 <div class="wms-col-12">
											 <label class="mylabel"><?php esc_html_e('Identifier / Name', 'koala-multiple-customer-addresses'); ?></label><span class="required">*</span>
											 <input placeholder="<?php esc_html_e('Office address', 'koala-multiple-customer-addresses'); ?>" class="inputsize" type="text" name="identifier_name_billing">
										 </div>
									 </div>
									<?php
					}
					?>
								 <div class="wms-row">
									 <div class="wms-col-6">
										 <label class="mylabel"><?php esc_html_e('First Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
										 <input class="name_size" type="text" name="first_name_billing">
									 </div>
									 <div class="wms-col-6">
										 <label class="mylabel"><?php esc_html_e('Last Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
										 <input class="name_size" type="text" name="last_name_billing">
									 </div>
								 </div>
								<?php
								$require_company_billing = get_option('require_company_field_billing');
								if ('1' === $require_company_billing) {
									?>
									 <div class="wms-row">
										 <div class="wms-col-12">
											 <label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
											 <input class="inputsize" type="text" name="copmany_name_billing_required">
										 </div>
									 </div>
									<?php
								} else {
									?>
									 <div class="wms-row">
										 <div class="wms-col-12">
											 <label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?></label>
											 <input class="inputsize" type="text" name="copmany_name_billing">
										 </div>
									 </div>
									<?php
								}
								?>
								 <div class="wms-row">
									 <div class="wms-col-6">
										 <label class="mylabel"><?php esc_html_e('Choose Country', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
										 <select name="country_name_billing" id="cor_countries_billing_front">
								<?php
								$countr_obj = new WC_Countries();
								$countries  = $countr_obj->__get('countries');
								foreach ($countries as $key => $country) {
									?>
												 <option value="<?php echo esc_html($key); ?>">
										<?php echo esc_html__($country, 'koala-multiple-customer-addresses'); ?>
												 </option>
												<?php
								}
								?>
										 </select>
									 </div>
									 <div class="wms-col-6">
										 <div class="state_val_add_billing_front">
										 </div>
									 </div>
								 </div>
								 <div class="wms-row">
									 <div class="wms-col-12">
										 <label class="mylabel"><?php esc_html_e('Street Address', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
										 <input type="text" class="inputsize" name="st_address_billing" placeholder="<?php esc_html_e('House number and street number', 'koala-multiple-customer-addresses'); ?>">
									 </div>
								 </div>
								 <div class="wms-row">
									 <div class="wms-col-12">
										 <input type="text" class="inputsize" name="st_address_billing2" placeholder="<?php esc_html_e('Apartment, suite, unit, etc.(optional)', 'koala-multiple-customer-addresses'); ?>">
									 </div>
								 </div>
								 <div class="wms-row">
									 <div class="wms-col-6">
										 <label class="mylabel"><?php esc_html_e('Town/City', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
										 <input class="inputsize" type="text" name="town_address_billing" placeholder="">
									 </div>
									 <div class="wms-col-6">
										 <label class="mylabel"><?php esc_html_e('Postal code', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
										 <input class="inputsize" type="text" name="postal_code_billing" placeholder="">
									 </div>
								 </div>
								 <div class="wms-row">
									 <div class="wms-col-6">
										 <label class="mylabel"><?php esc_html_e('Phone', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
										 <input class="inputsize" type="number" name="phone_billing" placeholder="">
									 </div>
									 <div class="wms-col-6">
										 <label class="mylabel"><?php esc_html_e('Email Address', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
										 <input class="inputsize" type="Email" name="email_billing" placeholder="">
									 </div>
								 </div>
								 <input type="hidden" name="user_id" value="<?php echo esc_attr(get_current_user_id()); ?>">
								 <div class="save_button1"><input type="button" class="buttonstyle cart_billing_values" name="cart_bill_save" value="Save"></div>
							 </div>
						 </div>
					 </form>
					<?php
	}
	public function cart_page_drop_down_billing() {
		$select_user_from_switch = get_option('wmsa_user_role');
		$user_id                 = get_current_user_id();

		$selected_data = (int) get_user_meta($user_id, 'default_billing_meta', true);

		if (isset($user_id) && 0 !== $user_id) {
			$role = current(wp_get_current_user()->roles);
			if (( is_array($select_user_from_switch) && in_array($role, (array) $select_user_from_switch) ) || ( empty($select_user_from_switch) )) {

				$wmsa_disable_bill = get_option('enable_disable_billing');
				if ('1' !== $wmsa_disable_bill) {
					$user_id      = get_current_user_id();
					$all_shipping = get_user_meta($user_id, 'all_billing_address', true);

					?>
								 <div id="refresh_bill">
						<?php
						if (!empty($all_shipping)) {
							?>
										 <h4>
								<?php
								$billing_checkout = get_option('billing_checkout_heading');
								if (isset($billing_checkout)) {
									echo esc_attr($billing_checkout);
								}
								?>
										 </h4>
										 <div id="find_val" class="find_val">
											 <input type="hidden" name="get_user_id" value="<?php echo esc_attr($user_id); ?>">
											 <select id="onchange_billing">
									<?php
									$select_label = get_option('default_select_key_field');
									if (!empty($select_label)) {
										?>
													 <option><?php echo esc_attr($select_label); ?></option>
													<?php
									} else {
										?>
													 <option><?php esc_html_e('Select an address', 'koala-multiple-customer-addresses'); ?></option>
													<?php
									}
									?>
									<?php
									foreach ($all_shipping as $key => $value) {
										?>
													 <option name="get_key" class="get_address_key" value="<?php echo esc_attr($key); ?>" <?php echo selected($key, $selected_data); ?>>
											<?php
											echo esc_attr($all_shipping[ $key ]['address_identifier_billing']);
											?>
													 </option>
										<?php
									}
									?>
											 </select><br>

								<?php
								$hide_add_new_check_bill = get_option('hide_add_new_check_bill');
								if ('1' !== $hide_add_new_check_bill) {
									$get_val = get_option('enable_disable_billing');
									if ('1' !== $get_val) {
										$diable_cap = get_option('disable_user_add_del_billing');
										if ('1' !== $diable_cap) {
											$max_addresses = get_option('max_num_billing');
											if (!empty($max_addresses) && 0 !== $max_addresses) {
												$all_shiiping_add = get_user_meta($user_id, 'all_billing_address', true);
												$count            = 0;
												if (isset($all_shiiping_add)) {
													foreach ($all_shiiping_add as $key_b => $value) {
														++$count;
													}
												}
												if ($count < $max_addresses) {
													$billing_label = get_option('billing_title_key_field');
													if (empty($billing_label)) {
														$billing_title = 'Add New Billing Address';
													} else {
														$billing_title = $billing_label;
													}
													?>
																 <a class="chk_a_style" id="add_cart_billing" name="cart_billing_model"><?php echo esc_html__($billing_title, 'koala-multiple-customer-addresses'); ?></a>
																<?php
												}
											} else {
												$billing_label = get_option('billing_title_key_field');
												if (empty($billing_label)) {
													$billing_title = 'Add New Billing Address';
												} else {
													$billing_title = $billing_label;
												}
												?>
															 <a class="chk_a_style" id="add_cart_billing" name="cart_billing_model"><?php echo esc_html__($billing_title, 'koala-multiple-customer-addresses'); ?></a>
															<?php
											}
										}
									}
								}

								?>
										 </div>
							<?php
						} else {

							?>

							<?php
							$hide_add_new_check_bill = get_option('hide_add_new_check_bill');
							if ('1' !== $hide_add_new_check_bill) {
								$get_val = get_option('enable_disable_billing');
								if ('1' !== $get_val) {
									$diable_cap = get_option('disable_user_add_del_billing');
									if ('1' !== $diable_cap) {
										$max_addresses = get_option('max_num_billing');
										if (!empty($max_addresses) && 0 !== $max_addresses) {
											$all_shiiping_add = get_user_meta($user_id, 'all_billing_address', true);
											$count            = 0;
											if (!empty($all_shiiping_add)) {
												foreach ($all_shiiping_add as $key_b => $value) {
													++$count;
												}
											}
											if ($count < $max_addresses) {
												$billing_label = get_option('billing_title_key_field');
												if (empty($billing_label)) {
													$billing_title = 'Add New Billing Address';
												} else {
													$billing_title = $billing_label;
												}
												?>
															 <a class="chk_a_style" id="add_cart_billing" name="cart_billing_model"><?php echo esc_html__($billing_title, 'koala-multiple-customer-addresses'); ?></a>
															<?php
											}
										} else {
											$billing_label = get_option('billing_title_key_field');
											if (empty($billing_label)) {
												$billing_title = 'Add New Billing Address';
											} else {
												$billing_title = $billing_label;
											}
											?>
														 <a class="chk_a_style" id="add_cart_billing" name="cart_billing_model"><?php echo esc_html__($billing_title, 'koala-multiple-customer-addresses'); ?></a>
														<?php
										}
									}
								}
							}
						}
						?>
								 </div>
					<?php
				}
			}
		}
	}
	public function cart_page_drop_down_shipping() {
		?>
					<div id="cart_modal_id_shipping" class="cart_model_class_shipping">
						<div class="cart_model_content_shipping">
							<span class="cart_m_exit_shipping">&times;</span>
							<div class="message"></div>
		<?php
		$getidentifier = get_option('disable_identifier_name');
		if ('1' !== $getidentifier) {
			?>
								<div class="wms-row">
									<div class="wms-col-12">
										<label class="mylabel"><?php esc_html_e('Identifier / Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
										<input placeholder="<?php esc_html_e('Example:Office address,Mary Jones,MJ 2145', 'koala-multiple-customer-addresses'); ?>" class="inputsize" type="text" required="true" id="identifier_name_shipping" name="identifier_name_shipping">
									</div>
								</div>
						<?php
		}
		?>
							<div class="wms-row">
								<div class="wms-col-6">
									<label class="mylabel"><?php esc_html_e('First Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									<input type="text" name="first_name_shipping" required="true">
								</div>
								<div class="wms-col-6">
									<label class="mylabel"><?php esc_html_e('Last Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									<input required="true" type="text" name="last_name_shipping">
								</div>
							</div>

					<?php
					$require_company_shipping = get_option('require_company_field_shipping');
					if ('1' === $require_company_shipping) {
						?>
								<div class="wms-row">
									<div class="wms-col-12">
										<label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
										<input required="true" class="inputsize" type="text" name="copmany_name_shipping_edit_required">
									</div>
								</div>
								<?php
					} else {
						?>
								<div class="wms-row">
									<div class="wms-col-12">
										<label class="mylabel"><?php esc_html_e('Company Name', 'koala-multiple-customer-addresses'); ?></label>
										<input required="true" class="inputsize" type="text" name="copmany_name_shipping">
									</div>
								</div>
								<?php
					}
					?>
							<div class="wms-row">
								<div class="wms-col-6">
									<label class="mylabel"><?php esc_html_e('Choose Country', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									<select name="country_name_shipping" id="cor_countries_shipping_front">
							<?php
							$countr_obj = new WC_Countries();
							$countries  = $countr_obj->__get('countries');
							foreach ($countries as $key => $country) {
								?>
											<option value="<?php echo esc_html($key); ?>">
									<?php echo esc_html__($country, 'koala-multiple-customer-addresses'); ?>

											</option>
											<?php
							}
							?>
									</select>
								</div>
								<div class="wms-col-6">
									<div class="state_val_add_shipping_front">
									</div>
								</div>
							</div>
							<div class="wms-row">
								<div class="wms-col-12">
									<label class="mylabel"><?php esc_html_e('Street Address', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									<input type="text" class="inputsize" placeholder="<?php esc_html_e('House number and street number', 'koala-multiple-customer-addresses'); ?>" name="st_address_shipping">
								</div>
							</div>
							<div class="wms-row">
								<div class="wms-col-12">
									<input type="text" placeholder="<?php esc_html_e('Apartment, suite, unit, etc.(optional)', 'koala-multiple-customer-addresses'); ?>" class="inputsize" name="st_address_shipping2">
								</div>
							</div>
							<div class="wms-row">
								<div class="wms-col-6">
									<label class="mylabel"><?php esc_html_e('Town/City', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									<input class="inputsize" type="text" name="town_address_shipping" placeholder="">
								</div>
								<div class="wms-col-6">
									<label class="mylabel"><?php esc_html_e('Postal code', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
									<input class="inputsize" type="text" name="pin_code_shipping" placeholder="">
								</div>
							</div>
							<?php
							$add_shipping_phone = get_option('add_shipping_phone_option');
							?>
							<div class="wms-row">
					<?php
					if ('1' === $add_shipping_phone) {
						$require_phone = get_option('require_shipping_phone');
						if ('1' === $require_phone) {
							?>
										<div class="wms-col-6">
											<label class="mylabel"><?php esc_html_e('Phone', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>

											<input class="inputsize" type="number" name="phone_shipping_required" placeholder="">
										</div>

										<?php
						} else {
							?>
										<div class="wms-col-6">
											<label class="mylabel"><?php esc_html_e('Phone', 'koala-multiple-customer-addresses'); ?></label>

											<input class="inputsize" type="number" name="phone_shipping" placeholder="">
										</div>
										<?php
						}
					}
					?>
					<?php
					$add_shipping_email = get_option('add_shipping_email_option');
					if ('1' === $add_shipping_email) {
						$require_email = get_option('require_shipping_email');
						if ('1' === $require_email) {
							?>
										<div class="wms-col-6">
											<label class="mylabel"><?php esc_html_e('Email Address', 'koala-multiple-customer-addresses'); ?><span class="required">*</span></label>
											<input class="inputsize" type="Email" name="email_shipping_required" placeholder="">
										</div>
										<?php
						} else {
							?>
										<div class="wms-col-6">
											<label class="mylabel"><?php esc_html_e('Email Address', 'koala-multiple-customer-addresses'); ?></label>
											<input class="inputsize" type="Email" name="email_shipping" placeholder="">
										</div>
										<?php
						}
					}
					?>
							</div>
							<input type="hidden" name="user_id" value="<?php echo esc_attr(get_current_user_id()); ?>">
							<div align="right"><input type="button" class="buttonstyle cart_shipping_values" name="shipping_form_submit_front" value="Save"></div>
						</div>
					</div>
					<?php
					$select_user_from_switch = get_option('wmsa_user_role');
					$user_id                 = get_current_user_id();
					$selected_data           = (int) get_user_meta($user_id, 'default_shipping_meta', true);
					if (isset($user_id) && 0 !== $user_id) {
						$role = current(wp_get_current_user()->roles);
						if (( is_array($select_user_from_switch) && in_array($role, (array) $select_user_from_switch) ) || ( empty($select_user_from_switch) )) {

							$wmsa_disable_ship = get_option('enable_disable_shipping');
							if ('1' !== $wmsa_disable_ship) {
								$user_id      = get_current_user_id();
								$all_shipping = get_user_meta($user_id, 'all_shipping_address', true);
								?>
								<div id="refresh_ship">
									<?php
									if (!empty($all_shipping)) {
										?>
										<h4>
											<?php
											$shipping_checkout = get_option('shipping_checkout_heading');
											if (isset($shipping_checkout)) {
												echo esc_attr__($shipping_checkout, 'koala-multiple-customer-addresses');
											}
											?>
										</h4>
										<div id="find_val_shipping" class="find_val_shipping">
											<input type="hidden" name="get_user_id" value="<?php echo esc_attr($user_id); ?>">
											<select id="onchange_shipping">
												<?php
												$select_label = get_option('default_select_key_field');
												if (!empty($select_label)) {
													?>
													<option><?php echo esc_attr($select_label); ?></option>
													<?php
												} else {
													?>
													<option><?php esc_html_e('Select an Address', 'koala-multiple-customer-addresses'); ?></option>
													<?php
												}
												?>
												<?php
												foreach ($all_shipping as $key => $value) {
													?>
													<option name="get_key" class="get_address_key" value="<?php echo esc_attr($key); ?>" <?php echo selected($key, $selected_data); ?>>
														<?php
														echo esc_attr($all_shipping[ $key ]['address_identifier_shipping']);
														?>
													</option>

													<?php
												}
												?>
											</select><br>
											<?php
											$hide_new_check_shipping = get_option('hide_add_new_check_ship');
											if ('1' !== $hide_new_check_shipping) {
												$disable_shipping = get_option('enable_disable_shipping');
												if ('1' !== $disable_shipping) {
													$diable_cap_shipping = get_option('disable_user_add_del_shipping');                                 
													if ('1' !== $diable_cap_shipping) {
														$max_addresses_shipping = get_option('max_num_shipping');
														if (!empty($max_addresses_shipping) && 0 !== $max_addresses_shipping) {
															$all_shiiping_add = get_user_meta($user_id, 'all_shipping_address', true);
															$count            = 0;
															foreach ($all_shiiping_add as $key_t => $value) {
																++$count;
															}
															if ($count < $max_addresses_shipping) {
																$shipping_label = get_option('shipping_title_key_field');
												
																if (empty($shipping_label)) {
																	$shipping_title = __('Add New Shipping Address', 'koala-multiple-customer-addresses');
																} else {
																	$shipping_title = $shipping_label;
																}
																?>
																<a id="add_cart_shipping" class="chk_a_style" name="cart_shipping_model"><?php echo esc_html__($shipping_title, 'koala-multiple-customer-addresses'); ?></a>
																<?php
															}
														} else {
															$shipping_label = get_option('shipping_title_key_field');
															if (empty($shipping_label)) {
																$shipping_title = __('Add New Shipping Address', 'koala-multiple-customer-addresses');
															} else {
																$shipping_title = $shipping_label;
															}
															?>
															<a id="add_cart_shipping" class="chk_a_style" name="cart_shipping_model"><?php echo esc_html__($shipping_title, 'koala-multiple-customer-addresses'); ?></a>
															<?php
														}
													}
												}
											}
											?>
										</div>
										<?php
									} else {
										?>
										<?php
										$hide_new_check_shipping = get_option('hide_add_new_check_ship');
										if ('1' !== $hide_new_check_shipping) {
											$disable_shipping = get_option('enable_disable_shipping');
											if ('1' !== $disable_shipping) {
												$diable_cap_shipping = get_option('disable_user_add_del_shipping');
												if ('1' !== $diable_cap_shipping) {
													$max_addresses_shipping = get_option('max_num_shipping');
													if (!empty($max_addresses_shipping) && 0 !== $max_addresses_shipping) {
														$all_shiiping_add = get_user_meta($user_id, 'all_shipping_address', true);
														$count            = 0;
														if (!empty($all_shiiping_add)) {
															foreach ($all_shiiping_add as $key_t => $value) {
																++$count;
															}
														}
														if ($count < $max_addresses_shipping) {
															$shipping_label = get_option('shipping_title_key_field');
															if (empty($shipping_label)) {
																$shipping_title = __('Add New Shipping Address', 'koala-multiple-customer-addresses');
															} else {
																$shipping_title = $shipping_label;
															}
															?>

															<a id="add_cart_shipping" class="chk_a_style" name="cart_shipping_model"><?php echo esc_html__($shipping_title, 'koala-multiple-customer-addresses'); ?></a>
															<?php
														}
													} else {
														$shipping_label = get_option('shipping_title_key_field');
														if (empty($shipping_label)) {
															$shipping_title = __('Add New Shipping Address', 'koala-multiple-customer-addresses');
														} else {
															$shipping_title = $shipping_label;
														}
														?>
														<a id="add_cart_shipping" class="chk_a_style" name="cart_shipping_model"><?php echo esc_html__($shipping_title, 'koala-multiple-customer-addresses'); ?></a>
														<?php
													}
												}
											}
										}
									}
									?>
								</div>
								<?php
							}
						}
					}
	}
}
			new Koala_WMSA_Front();
